@@ -2,7 +2,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, you can obtain one at https://mozilla.org/MPL/2.0/.
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
@@ -15,79 +15,7 @@ n=0
 DIGOPTS="-p ${PORT}"
 SENDCMD="$PERL $SYSTEMTESTTOP/send.pl 10.53.0.4 ${EXTRAPORT1}"
 
-# Check if response in file $1 has the correct TTL range.
-# The response record must have RRtype $2 and class IN (CLASS1).
-# Maximum TTL is given by $3.  This works in most cases where TTL is
-# the second word on the line.  TTL position can be adjusted with
-# setting the position $4, but that requires updating this function.
-check_ttl_range() {
-    file=$1
-    pos=$4
-
-    case "$pos" in
-    "3")
-    awk -v rrtype="$2" -v ttl="$3" '($4 == "IN" || $4 == "CLASS1" ) && $5 == rrtype { if ($3 <= ttl) { ok=1 } } END { exit(ok?0:1) }' < $file
-    ;;
-    *)
-    awk -v rrtype="$2" -v ttl="$3" '($3 == "IN" || $3 == "CLASS1" ) && $4 == rrtype { if ($2 <= ttl) { ok=1 } } END { exit(ok?0:1) }' < $file
-    ;;
-    esac
-
-   result=$?
-   [ $result -eq 0 ] || echo_i "ttl check failed"
-   return $result
-}
-
-#
-# test whether ans7/ans.pl will be able to send a UPDATE response.
-# if it can't, we will log that below.
-#
-if "$PERL" -e 'use Net::DNS; use Net::DNS::Packet; my $p = new Net::DNS::Packet; $p->header->opcode(5);' > /dev/null 2>&1
-then
-	checkupdate=1
-else
-	checkupdate=0
-fi
-
-if [ -x "$NSLOOKUP" -a $checkupdate -eq 1 ] ; then
-
-  n=`expr $n + 1`
-  echo_i "check nslookup handles UPDATE response ($n)"
-  ret=0
-  "$NSLOOKUP" -q=CNAME "-port=$PORT" foo.bar 10.53.0.7 > nslookup.out.test$n 2>&1 && ret=1
-  grep "Opcode mismatch" nslookup.out.test$n > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-fi
-
-if [ -x "$HOST" -a $checkupdate -eq 1 ] ; then
-
-  n=`expr $n + 1`
-  echo_i "check host handles UPDATE response ($n)"
-  ret=0
-  "$HOST" -t CNAME -p $PORT foo.bar 10.53.0.7 > host.out.test$n 2>&1 && ret=1
-  grep "Opcode mismatch" host.out.test$n > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-fi
-
-if [ -x "$DIG" ] ; then
-
-  if [ $checkupdate -eq 1 ] ; then
-
-    n=`expr $n + 1`
-    echo_i "check dig handles UPDATE response ($n)"
-    ret=0
-    $DIG $DIGOPTS @10.53.0.7 cname foo.bar > dig.out.test$n 2>&1 && ret=1
-    grep "Opcode mismatch" dig.out.test$n > /dev/null || ret=1
-    if [ $ret -ne 0 ]; then echo_i "failed"; fi
-    status=`expr $status + $ret`
-  else
-    echo_i "Skipped UPDATE handling test"
-  fi
-
+if [ -x ${DIG} ] ; then
   n=`expr $n + 1`
   echo_i "checking dig short form works ($n)"
   ret=0
@@ -101,7 +29,6 @@ if [ -x "$DIG" ] ; then
   ret=0
   $DIG $DIGOPTS @10.53.0.3 +split=4 -t sshfp foo.example > dig.out.test$n || ret=1
   grep " 9ABC DEF6 7890 " < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "SSHFP" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -110,7 +37,6 @@ if [ -x "$DIG" ] ; then
   ret=0
   $DIG $DIGOPTS @10.53.0.3 +unknownformat a a.example > dig.out.test$n || ret=1
   grep "CLASS1[ 	][ 	]*TYPE1[ 	][ 	]*\\\\# 4 0A000001" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "TYPE1" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -119,8 +45,7 @@ if [ -x "$DIG" ] ; then
   ret=0
   $DIG $DIGOPTS @10.53.0.3 -x 127.0.0.1 > dig.out.test$n 2>&1 || ret=1
   # doesn't matter if has answer
-  grep -i "127\\.in-addr\\.arpa\\." < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "SOA" 86400 || ret=1
+  grep -i "127\.in-addr\.arpa\." < dig.out.test$n > /dev/null || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -128,26 +53,23 @@ if [ -x "$DIG" ] ; then
   echo_i "checking dig over TCP works ($n)"
   ret=0
   $DIG $DIGOPTS +tcp @10.53.0.3 a a.example > dig.out.test$n || ret=1
-  grep "10\\.0\\.0\\.1$" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
+  grep "10\.0\.0\.1$" < dig.out.test$n > /dev/null || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
   n=`expr $n + 1`
-  echo_i "checking dig +multi +norrcomments works for DNSKEY (when default is rrcomments)($n)"
+  echo_i "checking dig +multi +norrcomments works for dnskey (when default is rrcomments)($n)"
   ret=0
-  $DIG $DIGOPTS +tcp @10.53.0.3 +multi +norrcomments -t DNSKEY dnskey.example > dig.out.test$n || ret=1
-  grep "; ZSK; alg = " < dig.out.test$n > /dev/null && ret=1
-  check_ttl_range dig.out.test$n "DNSKEY" 300 || ret=1
+  $DIG $DIGOPTS +tcp @10.53.0.3 +multi +norrcomments DNSKEY dnskey.example > dig.out.test$n || ret=1
+  grep "; ZSK; alg = RSAMD5 ; key id = 30795" < dig.out.test$n > /dev/null && ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
   n=`expr $n + 1`
-  echo_i "checking dig +multi +norrcomments works for SOA (when default is rrcomments)($n)"
+  echo_i "checking dig +multi +norrcomments works for soa (when default is rrcomments)($n)"
   ret=0
-  $DIG $DIGOPTS +tcp @10.53.0.3 +multi +norrcomments -t SOA example > dig.out.test$n || ret=1
-  grep "; serial" dig.out.test$n > /dev/null && ret=1
-  check_ttl_range dig.out.test$n "SOA" 300 || ret=1
+  $DIG $DIGOPTS +tcp @10.53.0.3 +multi +norrcomments SOA example > dig.out.test$n || ret=1
+  grep "; ZSK; alg = RSAMD5 ; key id = 30795" < dig.out.test$n > /dev/null && ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -156,7 +78,6 @@ if [ -x "$DIG" ] ; then
   ret=0
   $DIG $DIGOPTS +tcp @10.53.0.3 +rrcomments DNSKEY dnskey.example > dig.out.test$n || ret=1
   grep "; ZSK; alg = RSAMD5 ; key id = 30795" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "DNSKEY" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -184,12 +105,29 @@ if [ -x "$DIG" ] ; then
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
+  n=`expr $n + 1`
+  echo_i "checking dig multi flag is local($n)"
+  ret=0
+  $DIG $DIGOPTS +tcp @10.53.0.3 -t DNSKEY dnskey.example +nomulti dnskey.example +nomulti > dig.out.nn.$n || ret=1
+  $DIG $DIGOPTS +tcp @10.53.0.3 -t DNSKEY dnskey.example +multi dnskey.example +nomulti > dig.out.mn.$n || ret=1
+  $DIG $DIGOPTS +tcp @10.53.0.3 -t DNSKEY dnskey.example +nomulti dnskey.example +multi > dig.out.nm.$n || ret=1
+  $DIG $DIGOPTS +tcp @10.53.0.3 -t DNSKEY dnskey.example +multi dnskey.example +multi > dig.out.mm.$n || ret=1
+  lcnn=`wc -l < dig.out.nn.$n`
+  lcmn=`wc -l < dig.out.mn.$n`
+  lcnm=`wc -l < dig.out.nm.$n`
+  lcmm=`wc -l < dig.out.mm.$n`
+  test $lcmm -ge $lcnm || ret=1
+  test $lcmm -ge $lcmn || ret=1
+  test $lcnm -ge $lcnn || ret=1
+  test $lcmn -ge $lcnn || ret=1
+  if [ $ret != 0 ]; then echo_i "failed"; fi
+  status=`expr $status + $ret`
+
   n=`expr $n + 1`
   echo_i "checking dig +noheader-only works ($n)"
   ret=0
   $DIG $DIGOPTS +tcp @10.53.0.3 +noheader-only A example > dig.out.test$n || ret=1
   grep "Got answer:" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "SOA" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -224,7 +162,6 @@ if [ -x "$DIG" ] ; then
   $DIG $DIGOPTS +tcp @10.53.0.3 +zflag +qr A example > dig.out.test$n || ret=1
   sed -n '/Sending:/,/Got answer:/p' dig.out.test$n | grep "^;; flags: rd ad; MBZ: 0x4;" > /dev/null || ret=1
   sed -n '/Got answer:/,/AUTHORITY SECTION:/p' dig.out.test$n | grep "^;; flags: qr rd ra; QUERY: 1" > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "SOA" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -237,7 +174,6 @@ if [ -x "$DIG" ] ; then
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
-  n=`expr $n + 1`
   echo_i "checking dig +ttlunits works ($n)"
   ret=0
   $DIG $DIGOPTS +tcp @10.53.0.2 +ttlunits A weeks.example > dig.out.test$n || ret=1
@@ -287,7 +223,7 @@ if [ -x "$DIG" ] ; then
 
   n=`expr $n + 1`
   echo_i "checking dig @IPv6addr -4 A a.example ($n)"
-  if testsock6 fd92:7065:b8e:ffff::2 2>/dev/null
+  if $TESTSOCK6 fd92:7065:b8e:ffff::2 2>/dev/null
   then
     ret=0
     $DIG $DIGOPTS +tcp @fd92:7065:b8e:ffff::2 -4 A a.example > dig.out.test$n 2>&1 && ret=1
@@ -300,7 +236,7 @@ if [ -x "$DIG" ] ; then
 
   n=`expr $n + 1`
   echo_i "checking dig @IPv4addr -6 +mapped A a.example ($n)"
-  if testsock6 fd92:7065:b8e:ffff::2 2>/dev/null && [ "`uname -s`" != "OpenBSD" ]
+  if $TESTSOCK6 fd92:7065:b8e:ffff::2 2>/dev/null && [ `uname -s` != "OpenBSD" ]
   then
     ret=0
     ret=0
@@ -314,7 +250,7 @@ if [ -x "$DIG" ] ; then
 
   n=`expr $n + 1`
   echo_i "checking dig +tcp @IPv4addr -6 +nomapped A a.example ($n)"
-  if testsock6 fd92:7065:b8e:ffff::2 2>/dev/null
+  if $TESTSOCK6 fd92:7065:b8e:ffff::2 2>/dev/null
   then
     ret=0
     ret=0
@@ -328,7 +264,7 @@ if [ -x "$DIG" ] ; then
   n=`expr $n + 1`
 
   echo_i "checking dig +notcp @IPv4addr -6 +nomapped A a.example ($n)"
-  if testsock6 fd92:7065:b8e:ffff::2 2>/dev/null
+  if $TESTSOCK6 fd92:7065:b8e:ffff::2 2>/dev/null
   then
     ret=0
     ret=0
@@ -345,7 +281,6 @@ if [ -x "$DIG" ] ; then
   ret=0
   $DIG $DIGOPTS +tcp @10.53.0.2 +subnet=127.0.0.1 A a.example > dig.out.test$n 2>&1 || ret=1
   grep "CLIENT-SUBNET: 127.0.0.1/32/0" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -354,7 +289,6 @@ if [ -x "$DIG" ] ; then
   ret=0
   $DIG $DIGOPTS +tcp @10.53.0.2 +subnet=127.0.0.0 +subnet=127.0.0.1 A a.example > dig.out.test$n 2>&1 || ret=1
   grep "CLIENT-SUBNET: 127.0.0.1/32/0" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -380,7 +314,6 @@ if [ -x "$DIG" ] ; then
       esac
       grep "FORMERR" < dig.out.$i.test$n > /dev/null && ret=1
       grep "CLIENT-SUBNET: $addr/$i/0" < dig.out.$i.test$n > /dev/null || ret=1
-      check_ttl_range dig.out.$i.test$n "A" 300 || ret=1
   done
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
@@ -392,7 +325,6 @@ if [ -x "$DIG" ] ; then
   grep "status: NOERROR" < dig.out.test$n > /dev/null || ret=1
   grep "CLIENT-SUBNET: 0.0.0.0/0/0" < dig.out.test$n > /dev/null || ret=1
   grep "10.0.0.1" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -403,7 +335,6 @@ if [ -x "$DIG" ] ; then
   grep "status: NOERROR" < dig.out.test$n > /dev/null || ret=1
   grep "CLIENT-SUBNET: 0.0.0.0/0/0" < dig.out.test$n > /dev/null || ret=1
   grep "10.0.0.1" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -414,7 +345,6 @@ if [ -x "$DIG" ] ; then
   grep "status: NOERROR" < dig.out.test$n > /dev/null || ret=1
   grep "CLIENT-SUBNET: ::/0/0" < dig.out.test$n > /dev/null || ret=1
   grep "10.0.0.1" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -425,7 +355,6 @@ if [ -x "$DIG" ] ; then
   grep "status: NOERROR" < dig.out.test$n > /dev/null || ret=1
   grep "CLIENT-SUBNET: 0/0/0" < dig.out.test$n > /dev/null || ret=1
   grep "10.0.0.1" < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -442,12 +371,11 @@ if [ -x "$DIG" ] ; then
 
   n=`expr $n + 1`
   echo_i "checking dig +subnet with prefix lengths between byte boundaries ($n)"
-ret=0
+  ret=0
   for p in 9 10 11 12 13 14 15; do
     $DIG $DIGOPTS +tcp @10.53.0.2 +subnet=10.53/$p A a.example > dig.out.test.$p.$n 2>&1 || ret=1
     grep "FORMERR" < dig.out.test.$p.$n > /dev/null && ret=1
     grep "CLIENT-SUBNET.*/$p/0" < dig.out.test.$p.$n > /dev/null || ret=1
-    check_ttl_range dig.out.test.$p.$n "A" 300 || ret=1
   done
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
@@ -457,7 +385,6 @@ ret=0
   ret=0
   $DIG $DIGOPTS @10.53.0.3 +sp=4 -t sshfp foo.example > dig.out.test$n || ret=1
   grep " 9ABC DEF6 7890 " < dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "SSHFP" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -485,7 +412,6 @@ ret=0
   ret=0
   $DIG $DIGOPTS @10.53.0.3 +ednsopt=3 a.example > dig.out.test$n 2>&1 || ret=1
   grep 'NSID: .* ("ns3")' dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -494,19 +420,9 @@ ret=0
   ret=0
   $DIG $DIGOPTS @10.53.0.3 +ednsopt=nsid a.example > dig.out.test$n 2>&1 || ret=1
   grep 'NSID: .* ("ns3")' dig.out.test$n > /dev/null || ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
-  n=`expr $n + 1`
-  echo_i "checking ednsopt LLQ prints as expected ($n)"
-  ret=0
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=llq:0001000200001234567812345678fefefefe +qr a.example > dig.out.test$n 2>&1 || ret=1
-  pat='LLQ: Version: 1, Opcode: 2, Error: 0, Identifier: 1311768465173141112, Lifetime: 4278124286$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
   n=`expr $n + 1`
   echo_i "checking that dig warns about .local queries ($n)"
   ret=0
@@ -528,7 +444,6 @@ ret=0
   $DIG $DIGOPTS @10.53.0.3 +ednsopt=key-tag:00010002 a.example +qr > dig.out.test$n 2>&1 || ret=1
   grep "; KEY-TAG: 1, 2$" dig.out.test$n > /dev/null || ret=1
   grep "status: FORMERR" dig.out.test$n > /dev/null && ret=1
-  check_ttl_range dig.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -541,99 +456,6 @@ ret=0
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
-  n=`expr $n + 1`
-  echo_i "check that dig processes +ednsopt=client-tag:value ($n)"
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=client-tag:0001 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  grep "; CLIENT-TAG: 1$" dig.out.test$n > /dev/null || ret=1
-  grep "status: FORMERR" dig.out.test$n > /dev/null && ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that FORMERR is returned for a too short client-tag ($n)"
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=client-tag:01 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  grep "; CLIENT-TAG" dig.out.test$n > /dev/null || ret=1
-  grep "status: FORMERR" dig.out.test$n > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that FORMERR is returned for a too long client-tag ($n)"
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=client-tag:000001 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  grep "; CLIENT-TAG" dig.out.test$n > /dev/null || ret=1
-  grep "status: FORMERR" dig.out.test$n > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that dig processes +ednsopt=server-tag:value ($n)"
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=server-tag:0001 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  grep "; SERVER-TAG: 1$" dig.out.test$n > /dev/null || ret=1
-  grep "status: FORMERR" dig.out.test$n > /dev/null && ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that FORMERR is returned for a too short server-tag ($n)"
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=server-tag:01 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  grep "; SERVER-TAG" dig.out.test$n > /dev/null || ret=1
-  grep "status: FORMERR" dig.out.test$n > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that FORMERR is returned for a too long server-tag ($n)"
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=server-tag:000001 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  grep "; SERVER-TAG" dig.out.test$n > /dev/null || ret=1
-  grep "status: FORMERR" dig.out.test$n > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that Extended DNS Error 0 is printed correctly ($n)"
-  # First defined EDE code, additional text "foo".
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=ede:0000666f6f a.example +qr > dig.out.test$n 2>&1 || ret=1
-  pat='^; EDE: 0 (Other): (foo)$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that Extended DNS Error 24 is printed correctly ($n)"
-  # Last defined EDE code, no additional text.
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=ede:0018 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  pat='^; EDE: 24 (Invalid Data)$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that Extended DNS Error 25 is printed correctly ($n)"
-  # First undefined EDE code, additional text "foo".
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=ede:0019666f6f a.example +qr > dig.out.test$n 2>&1 || ret=1
-  pat='^; EDE: 25: (foo)$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that invalid Extended DNS Error (length 0) is printed ($n)"
-  # EDE payload is too short
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=ede a.example +qr > dig.out.test$n 2>&1 || ret=1
-  pat='^; EDE$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=$((n+1))
-  echo_i "check that invalid Extended DNS Error (length 1) is printed ($n)"
-  # EDE payload is too short
-  $DIG $DIGOPTS @10.53.0.3 +ednsopt=ede:00 a.example +qr > dig.out.test$n 2>&1 || ret=1
-  pat='^; EDE: 00 (".")$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
   n=`expr $n + 1`
   echo_i "check that dig handles malformed option '+ednsopt=:' gracefully ($n)"
   ret=0
@@ -642,44 +464,26 @@ ret=0
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
+  n=`expr $n + 1`
+  echo_i "check that dig gracefully handles bad escape in domain name ($n)"
+  ret=0
+  $DIG $DIGOPTS @10.53.0.3 '\0.' > dig.out.test$n 2>&1
+  digstatus=$?
+  echo digstatus=$digstatus >> dig.out.test$n
+  test $digstatus -eq 10 || ret=1
+  grep REQUIRE dig.out.test$n > /dev/null && ret=1
+  grep "is not a legal name (bad escape)" dig.out.test$n > /dev/null || ret=1
+  if [ $ret != 0 ]; then echo_i "failed"; fi
+  status=`expr $status + $ret`
+
   n=`expr $n + 1`
   echo_i "check that dig -q -m works ($n)"
   ret=0
   $DIG $DIGOPTS @10.53.0.3 -q -m > dig.out.test$n 2>&1
-  pat='^;-m\..*IN.*A$'
-  tr -d '\r' < dig.out.test$n | grep "$pat" > /dev/null || ret=1
+  grep '^;-m\..*IN.*A$' dig.out.test$n > /dev/null || ret=1
   grep "Dump of all outstanding memory allocations" dig.out.test$n > /dev/null && ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
+  if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
-
-  n=$((n+1))
-  echo_i "check that dig +bufsize=0 disables EDNS ($n)"
-  ret=0
-  $DIG $DIGOPTS @10.53.0.3 a.example +bufsize=0 +qr > dig.out.test$n 2>&1 || ret=1
-  grep "EDNS:" dig.out.test$n > /dev/null && ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=$((n+1))
-  echo_i "check that dig +bufsize=0 +edns sends EDNS with bufsize of 0 ($n)"
-  ret=0
-  $DIG $DIGOPTS @10.53.0.3 a.example +bufsize=0 +edns +qr > dig.out.test$n 2>&1 || ret=1
-  pat='EDNS:.* udp: 0$'
-  tr -d '\r' < dig.out.test$n | grep -E "$pat" > /dev/null || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=$((n+1))
-  echo_i "check that dig +bufsize restores default bufsize ($n)"
-  ret=0
-  $DIG $DIGOPTS @10.53.0.3 a.example +bufsize=0 +bufsize +qr > dig.out.test$n 2>&1 || ret=1
-  lines1232=`grep "EDNS:.* udp: 1232" dig.out.test$n | wc -l`
-  lines4096=`grep "EDNS:.* udp: 4096" dig.out.test$n | wc -l`
-  test $lines1232 -eq 1 || ret=1
-  test $lines4096 -eq 1 || ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
 else
   echo_i "$DIG is needed, so skipping these dig tests"
 fi
@@ -693,28 +497,12 @@ if [ -x ${MDIG} ] ; then
   grep "ednsopt no code point specified" dig.out.test$n > /dev/null || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "checking mdig +multi +norrcomments works for DNSKEY (when default is rrcomments)($n)"
-  ret=0
-  $MDIG $MDIGOPTS +tcp @10.53.0.3 +multi +norrcomments -t DNSKEY dnskey.example > dig.out.test$n || ret=1
-  grep " ; ZSK; alg = " < dig.out.test$n > /dev/null && ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "checking mdig +multi +norrcomments works for SOA (when default is rrcomments)($n)"
-  ret=0
-  $MDIG $MDIGOPTS +tcp @10.53.0.3 +multi +norrcomments -t SOA example > dig.out.test$n || ret=1
-  grep "; serial" < dig.out.test$n > /dev/null && ret=1
-  if [ $ret -ne 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
 else
   echo_i "$MDIG is needed, so skipping these mdig tests"
 fi
 
 # using delv insecure mode as not testing dnssec here
-DELVOPTS="+noroot +nodlv -p ${PORT}"
+DELVOPTS="-i -p ${PORT}"
 
 if [ -x ${DELV} ] ; then
   n=`expr $n + 1`
@@ -730,7 +518,6 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS @10.53.0.3 +split=4 -t sshfp foo.example > delv.out.test$n || ret=1
   grep " 9ABC DEF6 7890 " < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "SSHFP" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -739,7 +526,6 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS @10.53.0.3 +unknownformat a a.example > delv.out.test$n || ret=1
   grep "CLASS1[ 	][ 	]*TYPE1[ 	][ 	]*\\\\# 4 0A000001" < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "TYPE1" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -753,7 +539,7 @@ if [ -x ${DELV} ] ; then
 
   n=`expr $n + 1`
   echo_i "checking delv with IPv6 on IPv4 does not work ($n)"
-  if testsock6 fd92:7065:b8e:ffff::3 2>/dev/null
+  if $TESTSOCK6 fd92:7065:b8e:ffff::3 2>/dev/null
   then
     ret=0
     # following should fail because @IPv4 overrides earlier @IPv6 above
@@ -771,7 +557,7 @@ if [ -x ${DELV} ] ; then
 
   n=`expr $n + 1`
   echo_i "checking delv with IPv4 on IPv6 does not work ($n)"
-  if testsock6 fd92:7065:b8e:ffff::3 2>/dev/null
+  if $TESTSOCK6 fd92:7065:b8e:ffff::3 2>/dev/null
   then
     ret=0
     # following should fail because @IPv6 overrides earlier @IPv4 above
@@ -793,7 +579,6 @@ if [ -x ${DELV} ] ; then
   $DELV $DELVOPTS @10.53.0.3 -x 127.0.0.1 > delv.out.test$n 2>&1 || ret=1
   # doesn't matter if has answer
   grep -i "127\.in-addr\.arpa\." < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n '\\-ANY' 10800 3 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -802,25 +587,22 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS +tcp @10.53.0.3 a a.example > delv.out.test$n || ret=1
   grep "10\.0\.0\.1$" < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
   n=`expr $n + 1`
-  echo_i "checking delv +multi +norrcomments works for DNSKEY (when default is rrcomments)($n)"
+  echo_i "checking delv +multi +norrcomments works for dnskey (when default is rrcomments)($n)"
   ret=0
   $DELV $DELVOPTS +tcp @10.53.0.3 +multi +norrcomments DNSKEY dnskey.example > delv.out.test$n || ret=1
-  grep "; ZSK; alg = " < delv.out.test$n > /dev/null && ret=1
-  check_ttl_range delv.out.test$n "DNSKEY" 300 || ret=1
+  grep "; ZSK; alg = RSAMD5 ; key id = 30795" < delv.out.test$n > /dev/null && ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
   n=`expr $n + 1`
-  echo_i "checking delv +multi +norrcomments works for SOA (when default is rrcomments)($n)"
+  echo_i "checking delv +multi +norrcomments works for soa (when default is rrcomments)($n)"
   ret=0
   $DELV $DELVOPTS +tcp @10.53.0.3 +multi +norrcomments SOA example > delv.out.test$n || ret=1
-  grep "; ZSK; alg = " < delv.out.test$n > /dev/null && ret=1
-  check_ttl_range delv.out.test$n "SOA" 300 || ret=1
+  grep "; ZSK; alg = RSAMD5 ; key id = 30795" < delv.out.test$n > /dev/null && ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -829,7 +611,6 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS +tcp @10.53.0.3 +rrcomments DNSKEY dnskey.example > delv.out.test$n || ret=1
   grep "; ZSK; alg = RSAMD5 ; key id = 30795" < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "DNSKEY" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -876,7 +657,6 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS @10.53.0.3 +sp=4 -t sshfp foo.example > delv.out.test$n || ret=1
   grep " 9ABC DEF6 7890 " < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "SSHFP" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -893,7 +673,6 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS @10.53.0.3 -c IN -t a a.example > delv.out.test$n || ret=1
   grep "a.example." < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -902,7 +681,6 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS @10.53.0.3 -c CH -t a a.example > delv.out.test$n || ret=1
   grep "a.example." < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
@@ -911,28 +689,16 @@ if [ -x ${DELV} ] ; then
   ret=0
   $DELV $DELVOPTS @10.53.0.3 -c CH -t a a.example > delv.out.test$n || ret=1
   grep "a.example." < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n "A" 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
   n=`expr $n + 1`
   echo_i "check that delv -q -m works ($n)"
   ret=0
-  $DELV $DELVOPTS @10.53.0.3 -q -m > delv.out.test$n 2>&1 || ret=1
+  $DELV $DELVOPTS @10.53.0.3 -q -m > delv.out.test$n 2>&1
   grep '^; -m\..*[0-9]*.*IN.*ANY.*;' delv.out.test$n > /dev/null || ret=1
   grep "^add " delv.out.test$n > /dev/null && ret=1
   grep "^del " delv.out.test$n > /dev/null && ret=1
-  check_ttl_range delv.out.test$n '\\-ANY' 300 3 || ret=1
-  if [ $ret != 0 ]; then echo_i "failed"; fi
-  status=`expr $status + $ret`
-
-  n=`expr $n + 1`
-  echo_i "check that delv -t ANY works ($n)"
-  ret=0
-  $DELV $DELVOPTS @10.53.0.3 -t ANY example > delv.out.test$n 2>&1 || ret=1
-  grep "^example." < delv.out.test$n > /dev/null || ret=1
-  check_ttl_range delv.out.test$n NS 300 || ret=1
-  check_ttl_range delv.out.test$n SOA 300 || ret=1
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 else
