@@ -27,6 +27,8 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>
 
@@ -70,7 +72,7 @@ static dst_func_t *dst_t_func[DST_MAX_ALGS];
 static isc_entropy_t *dst_entropy_pool = NULL;
 static unsigned int dst_entropy_flags = 0;
 
-static isc_boolean_t dst_initialized = ISC_FALSE;
+static bool dst_initialized = false;
 
 void gss_log(int level, const char *fmt, ...) ISC_FORMAT_PRINTF(2, 3);
 
@@ -153,7 +155,7 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 	isc_result_t result;
 
 	REQUIRE(mctx != NULL);
-	REQUIRE(dst_initialized == ISC_FALSE);
+	REQUIRE(dst_initialized == false);
 
 #if !defined(OPENSSL) && !defined(PKCS11CRYPTO)
 	UNUSED(engine);
@@ -177,7 +179,7 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 		return (result);
 	isc_mem_setname(dst__memory_pool, "dst", NULL);
 #ifndef OPENSSL_LEAKS
-	isc_mem_setdestroycheck(dst__memory_pool, ISC_FALSE);
+	isc_mem_setdestroycheck(dst__memory_pool, false);
 #endif
 #else /* OPENSSL */
 	isc_mem_attach(mctx, &dst__memory_pool);
@@ -272,12 +274,12 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 	}
 #endif
 #endif /* defined(OPENSSL) || defined(PKCS11CRYPTO) */
-	dst_initialized = ISC_TRUE;
+	dst_initialized = true;
 	return (ISC_R_SUCCESS);
 
  out:
 	/* avoid immediate crash! */
-	dst_initialized = ISC_TRUE;
+	dst_initialized = true;
 	dst_lib_destroy();
 	return (result);
 }
@@ -285,8 +287,8 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 void
 dst_lib_destroy(void) {
 	int i;
-	RUNTIME_CHECK(dst_initialized == ISC_TRUE);
-	dst_initialized = ISC_FALSE;
+	RUNTIME_CHECK(dst_initialized == true);
+	dst_initialized = false;
 
 	for (i = 0; i < DST_MAX_ALGS; i++)
 		if (dst_t_func[i] != NULL && dst_t_func[i]->cleanup != NULL)
@@ -294,7 +296,7 @@ dst_lib_destroy(void) {
 #if defined(OPENSSL) || defined(PKCS11CRYPTO)
 #ifdef ISC_PLATFORM_CRYPTORANDOM
 	if (dst_entropy_pool != NULL) {
-		isc_entropy_usehook(dst_entropy_pool, ISC_FALSE);
+		isc_entropy_usehook(dst_entropy_pool, false);
 		isc_entropy_sethook(NULL);
 	}
 #endif
@@ -310,45 +312,41 @@ dst_lib_destroy(void) {
 		isc_entropy_detach(&dst_entropy_pool);
 }
 
-isc_boolean_t
+bool
 dst_algorithm_supported(unsigned int alg) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 
 	if (alg >= DST_MAX_ALGS || dst_t_func[alg] == NULL)
-		return (ISC_FALSE);
-	return (ISC_TRUE);
+		return (false);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dst_ds_digest_supported(unsigned int digest_type) {
+	return  (digest_type == DNS_DSDIGEST_SHA1 ||
+		 digest_type == DNS_DSDIGEST_SHA256 ||
 #if defined(HAVE_OPENSSL_GOST) || defined(HAVE_PKCS11_GOST)
-	return  (ISC_TF(digest_type == DNS_DSDIGEST_SHA1 ||
-			digest_type == DNS_DSDIGEST_SHA256 ||
-			digest_type == DNS_DSDIGEST_GOST ||
-			digest_type == DNS_DSDIGEST_SHA384));
-#else
-	return  (ISC_TF(digest_type == DNS_DSDIGEST_SHA1 ||
-			digest_type == DNS_DSDIGEST_SHA256 ||
-			digest_type == DNS_DSDIGEST_SHA384));
+		 digest_type == DNS_DSDIGEST_GOST ||
 #endif
+		 digest_type == DNS_DSDIGEST_SHA384);
 }
 
 isc_result_t
 dst_context_create(dst_key_t *key, isc_mem_t *mctx, dst_context_t **dctxp) {
 	return (dst_context_create4(key, mctx, DNS_LOGCATEGORY_GENERAL,
-				    ISC_TRUE, 0, dctxp));
+				    true, 0, dctxp));
 }
 
 isc_result_t
 dst_context_create2(dst_key_t *key, isc_mem_t *mctx,
 		    isc_logcategory_t *category, dst_context_t **dctxp)
 {
-	return (dst_context_create4(key, mctx, category, ISC_TRUE, 0, dctxp));
+	return (dst_context_create4(key, mctx, category, true, 0, dctxp));
 }
 
 isc_result_t
 dst_context_create3(dst_key_t *key, isc_mem_t *mctx,
-		    isc_logcategory_t *category, isc_boolean_t useforsigning,
+		    isc_logcategory_t *category, bool useforsigning,
 		    dst_context_t **dctxp)
 {
 	return (dst_context_create4(key, mctx, category,
@@ -357,13 +355,13 @@ dst_context_create3(dst_key_t *key, isc_mem_t *mctx,
 
 isc_result_t
 dst_context_create4(dst_key_t *key, isc_mem_t *mctx,
-		    isc_logcategory_t *category, isc_boolean_t useforsigning,
+		    isc_logcategory_t *category, bool useforsigning,
 		    int maxbits, dst_context_t **dctxp)
 {
 	dst_context_t *dctx;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(mctx != NULL);
 	REQUIRE(dctxp != NULL && *dctxp == NULL);
@@ -440,7 +438,7 @@ dst_context_sign(dst_context_t *dctx, isc_buffer_t *sig) {
 	if (key->func->sign == NULL)
 		return (DST_R_NOTPRIVATEKEY);
 	if (key->func->isprivate == NULL ||
-	    key->func->isprivate(key) == ISC_FALSE)
+	    key->func->isprivate(key) == false)
 		return (DST_R_NOTPRIVATEKEY);
 
 	return (key->func->sign(dctx, sig));
@@ -483,7 +481,7 @@ isc_result_t
 dst_key_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 		      isc_buffer_t *secret)
 {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(pub) && VALID_KEY(priv));
 	REQUIRE(secret != NULL);
 
@@ -498,7 +496,7 @@ dst_key_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 	    priv->func->computesecret == NULL)
 		return (DST_R_KEYCANNOTCOMPUTESECRET);
 
-	if (dst_key_isprivate(priv) == ISC_FALSE)
+	if (dst_key_isprivate(priv) == false)
 		return (DST_R_NOTPRIVATEKEY);
 
 	return (pub->func->computesecret(pub, priv, secret));
@@ -508,7 +506,7 @@ isc_result_t
 dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 	isc_result_t ret = ISC_R_SUCCESS;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 
@@ -517,13 +515,13 @@ dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 	if (key->func->tofile == NULL)
 		return (DST_R_UNSUPPORTEDALG);
 
-	if (type & DST_TYPE_PUBLIC) {
+	if ((type & DST_TYPE_PUBLIC) != 0) {
 		ret = write_public_key(key, type, directory);
 		if (ret != ISC_R_SUCCESS)
 			return (ret);
 	}
 
-	if ((type & DST_TYPE_PRIVATE) &&
+	if (((type & DST_TYPE_PRIVATE) != 0) &&
 	    (key->key_flags & DNS_KEYFLAG_TYPEMASK) != DNS_KEYTYPE_NOKEY)
 		return (key->func->tofile(key, directory));
 	else
@@ -531,11 +529,11 @@ dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 }
 
 void
-dst_key_setexternal(dst_key_t *key, isc_boolean_t value) {
+dst_key_setexternal(dst_key_t *key, bool value) {
 	key->external = value;
 }
 
-isc_boolean_t
+bool
 dst_key_isexternal(dst_key_t *key) {
 	return (key->external);
 }
@@ -547,7 +545,7 @@ dst_key_getfilename(dns_name_t *name, dns_keytag_t id,
 {
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -576,7 +574,7 @@ dst_key_fromfile(dns_name_t *name, dns_keytag_t id,
 	isc_buffer_t buf;
 	dst_key_t *key;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -625,7 +623,7 @@ dst_key_fromnamedfile(const char *filename, const char *dirname,
 	int newfilenamelen = 0;
 	isc_lex_t *lex = NULL;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(filename != NULL);
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -724,7 +722,7 @@ dst_key_fromnamedfile(const char *filename, const char *dirname,
 
 isc_result_t
 dst_key_todns(const dst_key_t *key, isc_buffer_t *target) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(target != NULL);
 
@@ -735,15 +733,15 @@ dst_key_todns(const dst_key_t *key, isc_buffer_t *target) {
 
 	if (isc_buffer_availablelength(target) < 4)
 		return (ISC_R_NOSPACE);
-	isc_buffer_putuint16(target, (isc_uint16_t)(key->key_flags & 0xffff));
-	isc_buffer_putuint8(target, (isc_uint8_t)key->key_proto);
-	isc_buffer_putuint8(target, (isc_uint8_t)key->key_alg);
+	isc_buffer_putuint16(target, (uint16_t)(key->key_flags & 0xffff));
+	isc_buffer_putuint8(target, (uint8_t)key->key_proto);
+	isc_buffer_putuint8(target, (uint8_t)key->key_alg);
 
-	if (key->key_flags & DNS_KEYFLAG_EXTENDED) {
+	if ((key->key_flags & DNS_KEYFLAG_EXTENDED) != 0) {
 		if (isc_buffer_availablelength(target) < 2)
 			return (ISC_R_NOSPACE);
 		isc_buffer_putuint16(target,
-				     (isc_uint16_t)((key->key_flags >> 16)
+				     (uint16_t)((key->key_flags >> 16)
 						    & 0xffff));
 	}
 
@@ -757,8 +755,8 @@ isc_result_t
 dst_key_fromdns(const dns_name_t *name, dns_rdataclass_t rdclass,
 		isc_buffer_t *source, isc_mem_t *mctx, dst_key_t **keyp)
 {
-	isc_uint8_t alg, proto;
-	isc_uint32_t flags, extflags;
+	uint8_t alg, proto;
+	uint32_t flags, extflags;
 	dst_key_t *key = NULL;
 	dns_keytag_t id, rid;
 	isc_region_t r;
@@ -777,7 +775,7 @@ dst_key_fromdns(const dns_name_t *name, dns_rdataclass_t rdclass,
 	id = dst_region_computeid(&r, alg);
 	rid = dst_region_computerid(&r, alg);
 
-	if (flags & DNS_KEYFLAG_EXTENDED) {
+	if ((flags & DNS_KEYFLAG_EXTENDED) != 0) {
 		if (isc_buffer_remaininglength(source) < 2)
 			return (DST_R_INVALIDPUBLICKEY);
 		extflags = isc_buffer_getuint16(source);
@@ -823,7 +821,7 @@ dst_key_frombuffer(const dns_name_t *name, unsigned int alg,
 
 isc_result_t
 dst_key_tobuffer(const dst_key_t *key, isc_buffer_t *target) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(target != NULL);
 
@@ -840,7 +838,7 @@ dst_key_privatefrombuffer(dst_key_t *key, isc_buffer_t *buffer) {
 	isc_lex_t *lex = NULL;
 	isc_result_t result = ISC_R_SUCCESS;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(!dst_key_isprivate(key));
 	REQUIRE(buffer != NULL);
@@ -894,6 +892,9 @@ dst_key_fromgssapi(const dns_name_t *name, gss_ctx_id_t gssctx,
 	*keyp = key;
 	result = ISC_R_SUCCESS;
 out:
+	if (result != ISC_R_SUCCESS) {
+		dst_key_free(&key);
+	}
 	return result;
 }
 
@@ -906,7 +907,7 @@ dst_key_buildinternal(const dns_name_t *name, unsigned int alg,
 	dst_key_t *key;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -940,7 +941,7 @@ dst_key_fromlabel(const dns_name_t *name, int alg, unsigned int flags,
 	dst_key_t *key;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -995,7 +996,7 @@ dst_key_generate2(const dns_name_t *name, unsigned int alg,
 	dst_key_t *key;
 	isc_result_t ret;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -1035,7 +1036,7 @@ dst_key_generate2(const dns_name_t *name, unsigned int alg,
 }
 
 isc_result_t
-dst_key_getnum(const dst_key_t *key, int type, isc_uint32_t *valuep)
+dst_key_getnum(const dst_key_t *key, int type, uint32_t *valuep)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(valuep != NULL);
@@ -1047,12 +1048,12 @@ dst_key_getnum(const dst_key_t *key, int type, isc_uint32_t *valuep)
 }
 
 void
-dst_key_setnum(dst_key_t *key, int type, isc_uint32_t value)
+dst_key_setnum(dst_key_t *key, int type, uint32_t value)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_NUMERIC);
 	key->nums[type] = value;
-	key->numset[type] = ISC_TRUE;
+	key->numset[type] = true;
 }
 
 void
@@ -1060,7 +1061,7 @@ dst_key_unsetnum(dst_key_t *key, int type)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_NUMERIC);
-	key->numset[type] = ISC_FALSE;
+	key->numset[type] = false;
 }
 
 isc_result_t
@@ -1079,14 +1080,14 @@ dst_key_settime(dst_key_t *key, int type, isc_stdtime_t when) {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_TIMES);
 	key->times[type] = when;
-	key->timeset[type] = ISC_TRUE;
+	key->timeset[type] = true;
 }
 
 void
 dst_key_unsettime(dst_key_t *key, int type) {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_TIMES);
-	key->timeset[type] = ISC_FALSE;
+	key->timeset[type] = false;
 }
 
 isc_result_t
@@ -1106,41 +1107,41 @@ dst_key_setprivateformat(dst_key_t *key, int major, int minor) {
 	key->fmt_minor = minor;
 }
 
-static isc_boolean_t
+static bool
 comparekeys(const dst_key_t *key1, const dst_key_t *key2,
-	    isc_boolean_t match_revoked_key,
-	    isc_boolean_t (*compare)(const dst_key_t *key1,
+	    bool match_revoked_key,
+	    bool (*compare)(const dst_key_t *key1,
 				     const dst_key_t *key2))
 {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key1));
 	REQUIRE(VALID_KEY(key2));
 
 	if (key1 == key2)
-		return (ISC_TRUE);
+		return (true);
 
 	if (key1->key_alg != key2->key_alg)
-		return (ISC_FALSE);
+		return (false);
 
 	if (key1->key_id != key2->key_id) {
 		if (!match_revoked_key)
-			return (ISC_FALSE);
+			return (false);
 #ifndef PK11_MD5_DISABLE
 		if (key1->key_alg == DST_ALG_RSAMD5)
-			return (ISC_FALSE);
+			return (false);
 #endif
 		if ((key1->key_flags & DNS_KEYFLAG_REVOKE) ==
 		    (key2->key_flags & DNS_KEYFLAG_REVOKE))
-			return (ISC_FALSE);
+			return (false);
 		if (key1->key_id != key2->key_rid &&
 		    key1->key_rid != key2->key_id)
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	if (compare != NULL)
 		return (compare(key1, key2));
 	else
-		return (ISC_FALSE);
+		return (false);
 }
 
 
@@ -1148,7 +1149,7 @@ comparekeys(const dst_key_t *key1, const dst_key_t *key2,
  * Compares only the public portion of two keys, by converting them
  * both to wire format and comparing the results.
  */
-static isc_boolean_t
+static bool
 pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_result_t result;
 	unsigned char buf1[DST_KEY_MAXSIZE], buf2[DST_KEY_MAXSIZE];
@@ -1158,7 +1159,7 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_buffer_init(&b1, buf1, sizeof(buf1));
 	result = dst_key_todns(key1, &b1);
 	if (result != ISC_R_SUCCESS)
-		return (ISC_FALSE);
+		return (false);
 	/* Zero out flags. */
 	buf1[0] = buf1[1] = 0;
 	if ((key1->key_flags & DNS_KEYFLAG_EXTENDED) != 0)
@@ -1167,7 +1168,7 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_buffer_init(&b2, buf2, sizeof(buf2));
 	result = dst_key_todns(key2, &b2);
 	if (result != ISC_R_SUCCESS)
-		return (ISC_FALSE);
+		return (false);
 	/* Zero out flags. */
 	buf2[0] = buf2[1] = 0;
 	if ((key2->key_flags & DNS_KEYFLAG_EXTENDED) != 0)
@@ -1186,42 +1187,42 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 		memmove(&buf2[4], &buf2[6], r2.length - 6);
 		r2.length -= 2;
 	}
-	return (ISC_TF(isc_region_compare(&r1, &r2) == 0));
+	return (isc_region_compare(&r1, &r2) == 0);
 }
 
-isc_boolean_t
+bool
 dst_key_compare(const dst_key_t *key1, const dst_key_t *key2) {
-	return (comparekeys(key1, key2, ISC_FALSE, key1->func->compare));
+	return (comparekeys(key1, key2, false, key1->func->compare));
 }
 
-isc_boolean_t
+bool
 dst_key_pubcompare(const dst_key_t *key1, const dst_key_t *key2,
-		   isc_boolean_t match_revoked_key)
+		   bool match_revoked_key)
 {
 	return (comparekeys(key1, key2, match_revoked_key, pub_compare));
 }
 
 
-isc_boolean_t
+bool
 dst_key_paramcompare(const dst_key_t *key1, const dst_key_t *key2) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key1));
 	REQUIRE(VALID_KEY(key2));
 
 	if (key1 == key2)
-		return (ISC_TRUE);
+		return (true);
 	if (key1->key_alg == key2->key_alg &&
 	    key1->func->paramcompare != NULL &&
-	    key1->func->paramcompare(key1, key2) == ISC_TRUE)
-		return (ISC_TRUE);
+	    key1->func->paramcompare(key1, key2) == true)
+		return (true);
 	else
-		return (ISC_FALSE);
+		return (false);
 }
 
 void
 dst_key_attach(dst_key_t *source, dst_key_t **target) {
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(target != NULL && *target == NULL);
 	REQUIRE(VALID_KEY(source));
 
@@ -1235,7 +1236,7 @@ dst_key_free(dst_key_t **keyp) {
 	dst_key_t *key;
 	unsigned int refs;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(keyp != NULL && VALID_KEY(*keyp));
 
 	key = *keyp;
@@ -1264,7 +1265,7 @@ dst_key_free(dst_key_t **keyp) {
 	*keyp = NULL;
 }
 
-isc_boolean_t
+bool
 dst_key_isprivate(const dst_key_t *key) {
 	REQUIRE(VALID_KEY(key));
 	INSIST(key->func->isprivate != NULL);
@@ -1285,7 +1286,7 @@ dst_key_buildfilename(const dst_key_t *key, int type,
 
 isc_result_t
 dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(n != NULL);
 
@@ -1355,7 +1356,7 @@ dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
 
 isc_result_t
 dst_key_secretsize(const dst_key_t *key, unsigned int *n) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(n != NULL);
 
@@ -1374,7 +1375,7 @@ dst_key_secretsize(const dst_key_t *key, unsigned int *n) {
  * Set the flags on a key, then recompute the key ID
  */
 isc_result_t
-dst_key_setflags(dst_key_t *key, isc_uint32_t flags) {
+dst_key_setflags(dst_key_t *key, uint32_t flags) {
 	REQUIRE(VALID_KEY(key));
 	key->key_flags = flags;
 	return (computeid(key));
@@ -1411,7 +1412,7 @@ dst_key_restore(dns_name_t *name, unsigned int alg, unsigned int flags,
 	isc_result_t result;
 	dst_key_t *key;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(keyp != NULL && *keyp == NULL);
 
 	if (alg >= DST_MAX_ALGS || dst_t_func[alg] == NULL)
@@ -1490,14 +1491,14 @@ get_key_struct(const dns_name_t *name, unsigned int alg,
 	key->fmt_minor = 0;
 	for (i = 0; i < (DST_MAX_TIMES + 1); i++) {
 		key->times[i] = 0;
-		key->timeset[i] = ISC_FALSE;
+		key->timeset[i] = false;
 	}
-	key->inactive = ISC_FALSE;
+	key->inactive = false;
 	key->magic = KEY_MAGIC;
 	return (key);
 }
 
-isc_boolean_t
+bool
 dst_key_inactive(const dst_key_t *key) {
 
 	REQUIRE(VALID_KEY(key));
@@ -1506,7 +1507,7 @@ dst_key_inactive(const dst_key_t *key) {
 }
 
 void
-dst_key_setinactive(dst_key_t *key, isc_boolean_t inactive) {
+dst_key_setinactive(dst_key_t *key, bool inactive) {
 
 	REQUIRE(VALID_KEY(key));
 
@@ -1530,7 +1531,7 @@ dst_key_read_public(const char *filename, int type,
 	unsigned int opt = ISC_LEXOPT_DNSMULTILINE;
 	dns_rdataclass_t rdclass = dns_rdataclass_in;
 	isc_lexspecials_t specials;
-	isc_uint32_t ttl = 0;
+	uint32_t ttl = 0;
 	isc_result_t result;
 	dns_rdatatype_t keytype;
 
@@ -1622,7 +1623,7 @@ dst_key_read_public(const char *filename, int type,
 
 	isc_buffer_init(&b, rdatabuf, sizeof(rdatabuf));
 	ret = dns_rdata_fromtext(&rdata, rdclass, keytype, lex, NULL,
-				 ISC_FALSE, mctx, &b, NULL);
+				 false, mctx, &b, NULL);
 	if (ret != ISC_R_SUCCESS)
 		goto cleanup;
 
@@ -1639,9 +1640,9 @@ dst_key_read_public(const char *filename, int type,
 	return (ret);
 }
 
-static isc_boolean_t
+static bool
 issymmetric(const dst_key_t *key) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 
 	/* XXXVIX this switch statement is too sparse to gen a jump table. */
@@ -1665,7 +1666,7 @@ issymmetric(const dst_key_t *key) {
 	case DST_ALG_ECDSA384:
 	case DST_ALG_ED25519:
 	case DST_ALG_ED448:
-		return (ISC_FALSE);
+		return (false);
 #ifndef PK11_MD5_DISABLE
 	case DST_ALG_HMACMD5:
 #endif
@@ -1675,9 +1676,9 @@ issymmetric(const dst_key_t *key) {
 	case DST_ALG_HMACSHA384:
 	case DST_ALG_HMACSHA512:
 	case DST_ALG_GSSAPI:
-		return (ISC_TRUE);
+		return (true);
 	default:
-		return (ISC_FALSE);
+		return (false);
 	}
 }
 
@@ -1869,7 +1870,7 @@ buildfilename(dns_name_t *name, dns_keytag_t id,
 	if (isc_buffer_availablelength(out) < 1)
 		return (ISC_R_NOSPACE);
 	isc_buffer_putstr(out, "K");
-	result = dns_name_tofilenametext(name, ISC_FALSE, out);
+	result = dns_name_tofilenametext(name, false, out);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
@@ -1935,7 +1936,7 @@ frombuffer(const dns_name_t *name, unsigned int alg, unsigned int flags,
 
 static isc_result_t
 algorithm_status(unsigned int alg) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 
 	if (dst_algorithm_supported(alg))
 		return (ISC_R_SUCCESS);
@@ -1980,7 +1981,7 @@ addsuffix(char *filename, int len, const char *odirname,
 }
 
 isc_result_t
-dst__entropy_getdata(void *buf, unsigned int len, isc_boolean_t pseudo) {
+dst__entropy_getdata(void *buf, unsigned int len, bool pseudo) {
 	unsigned int flags = dst_entropy_flags;
 
 	if (dst_entropy_pool == NULL)
@@ -2015,7 +2016,7 @@ dst__entropy_status(void) {
 	unsigned int flags = dst_entropy_flags;
 	isc_result_t ret;
 	unsigned char buf[32];
-	static isc_boolean_t first = ISC_TRUE;
+	static bool first = true;
 
 	if (dst_entropy_pool == NULL)
 		return (0);
@@ -2028,7 +2029,7 @@ dst__entropy_status(void) {
 		INSIST(ret == ISC_R_SUCCESS);
 		isc_entropy_putdata(dst_entropy_pool, buf,
 				    sizeof(buf), 2 * sizeof(buf));
-		first = ISC_FALSE;
+		first = false;
 	}
 #endif
 	return (isc_entropy_status(dst_entropy_pool));
