@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -29,6 +29,7 @@
 #include <isc/buffer.h>
 #include <isc/lang.h>
 #include <isc/magic.h>
+#include <isc/refcount.h>
 #include <isc/rwlock.h>
 #include <isc/stdtime.h>
 #include <isc/task.h>
@@ -52,7 +53,6 @@ struct dns_ntatable {
 	/* Locked by rwlock. */
 	uint32_t		references;
 	dns_rbt_t		*table;
-	bool	   		shuttingdown;
 };
 
 #define NTATABLE_MAGIC		ISC_MAGIC('N', 'T', 'A', 't')
@@ -117,7 +117,7 @@ dns_ntatable_detach(dns_ntatable_t **ntatablep);
  */
 
 isc_result_t
-dns_ntatable_add(dns_ntatable_t *ntatable, dns_name_t *name,
+dns_ntatable_add(dns_ntatable_t *ntatable, const dns_name_t *name,
 		 bool force, isc_stdtime_t now,
 		 uint32_t lifetime);
 /*%<
@@ -145,7 +145,7 @@ dns_ntatable_add(dns_ntatable_t *ntatable, dns_name_t *name,
  */
 
 isc_result_t
-dns_ntatable_delete(dns_ntatable_t *ntatable, dns_name_t *keyname);
+dns_ntatable_delete(dns_ntatable_t *ntatable, const dns_name_t *keyname);
 /*%<
  * Delete node(s) from 'ntatable' matching name 'keyname'
  *
@@ -164,7 +164,7 @@ dns_ntatable_delete(dns_ntatable_t *ntatable, dns_name_t *keyname);
 
 bool
 dns_ntatable_covered(dns_ntatable_t *ntatable, isc_stdtime_t now,
-		     dns_name_t *name, dns_name_t *anchor);
+		     const dns_name_t *name, const dns_name_t *anchor);
 /*%<
  * Return true if 'name' is below a non-expired negative trust
  * anchor which in turn is at or below 'anchor'.
@@ -200,13 +200,6 @@ dns_ntatable_save(dns_ntatable_t *ntatable, FILE *fp);
 /*%<
  * Save the NTA table to the file opened as 'fp', for later loading.
  */
-
-void
-dns_ntatable_shutdown(dns_ntatable_t *ntatable);
-/*%<
- * Cancel future checks to see if NTAs can be removed.
- */
-
 ISC_LANG_ENDDECLS
 
 #endif /* DNS_NTA_H */
