@@ -9,8 +9,6 @@
  * information regarding copyright ownership.
  */
 
-/* $Id$ */
-
 
 #ifndef DNS_RPZ_H
 #define DNS_RPZ_H 1
@@ -23,6 +21,8 @@
 #include <isc/lang.h>
 #include <isc/refcount.h>
 #include <isc/rwlock.h>
+#include <isc/time.h>
+#include <isc/timer.h>
 
 #include <dns/fixedname.h>
 #include <dns/rdata.h>
@@ -45,7 +45,6 @@ ISC_LANG_BEGINDECLS
 #define DNS_RPZ_DROP_NAME	DNS_RPZ_PREFIX"drop"
 #define DNS_RPZ_TCP_ONLY_NAME	DNS_RPZ_PREFIX"tcp-only"
 
-
 typedef uint8_t		dns_rpz_prefix_t;
 
 typedef enum {
@@ -126,20 +125,38 @@ struct dns_rpz_triggers {
  * A single response policy zone.
  */
 typedef struct dns_rpz_zone dns_rpz_zone_t;
+typedef struct dns_rpz_zones dns_rpz_zones_t;
+
 struct dns_rpz_zone {
-	isc_refcount_t	refs;
-	dns_rpz_num_t	num;		/* ordinal in list of policy zones */
-	dns_name_t	origin;		/* Policy zone name */
-	dns_name_t	client_ip;	/* DNS_RPZ_CLIENT_IP_ZONE.origin. */
-	dns_name_t	ip;		/* DNS_RPZ_IP_ZONE.origin. */
-	dns_name_t	nsdname;	/* DNS_RPZ_NSDNAME_ZONE.origin */
-	dns_name_t	nsip;		/* DNS_RPZ_NSIP_ZONE.origin. */
-	dns_name_t	passthru;	/* DNS_RPZ_PASSTHRU_NAME. */
-	dns_name_t	drop;		/* DNS_RPZ_DROP_NAME. */
-	dns_name_t	tcp_only;	/* DNS_RPZ_TCP_ONLY_NAME. */
-	dns_name_t	cname;		/* override value for ..._CNAME */
-	dns_ttl_t	max_policy_ttl;
+	isc_refcount_t	 refs;
+	dns_rpz_num_t	 num;		/* ordinal in list of policy zones */
+	dns_name_t	 origin;	/* Policy zone name */
+	dns_name_t	 client_ip;	/* DNS_RPZ_CLIENT_IP_ZONE.origin. */
+	dns_name_t	 ip;		/* DNS_RPZ_IP_ZONE.origin. */
+	dns_name_t	 nsdname;	/* DNS_RPZ_NSDNAME_ZONE.origin */
+	dns_name_t	 nsip;		/* DNS_RPZ_NSIP_ZONE.origin. */
+	dns_name_t	 passthru;	/* DNS_RPZ_PASSTHRU_NAME. */
+	dns_name_t	 drop;		/* DNS_RPZ_DROP_NAME. */
+	dns_name_t	 tcp_only;	/* DNS_RPZ_TCP_ONLY_NAME. */
+	dns_name_t	 cname;		/* override value for ..._CNAME */
+	dns_ttl_t	 max_policy_ttl;
 	dns_rpz_policy_t policy;	/* DNS_RPZ_POLICY_GIVEN or override */
+
+	uint32_t	 min_update_interval;/* minimal interval between updates */
+	isc_ht_t	 *nodes;	/* entries in zone */
+	dns_rpz_zones_t	 *rpzs;		/* owner */
+	isc_time_t	 lastupdated;	/* last time the zone was processed */
+	bool	 updatepending;	/* there is an update pending/waiting */
+	bool	 updaterunning;	/* there is an update running */
+	dns_db_t	 *db;		/* zones database */
+	dns_dbversion_t	 *dbversion;	/* version we will be updating to */
+	dns_db_t	 *updb;		/* zones database we're working on */
+	dns_dbversion_t	 *updbversion;	/* version we're currently working on */
+	dns_dbiterator_t *updbit;	/* iterator to use when updating */
+	isc_ht_t	 *newnodes;	/* entries in zone being updated */
+	bool	 db_registered;	/* is the notify event registered? */
+	isc_timer_t	 *updatetimer;
+	isc_event_t	 updateevent;
 };
 
 /*
@@ -174,6 +191,9 @@ typedef struct dns_rpz_popt dns_rpz_popt_t;
 struct dns_rpz_popt {
 	dns_rpz_zbits_t	    no_rd_ok;
 	dns_rpz_zbits_t	    no_log;
+	dns_rpz_zbits_t	    nsip_on;
+	dns_rpz_zbits_t	    nsdname_on;
+	bool	    dnsrps_enabled;
 	bool	    break_dnssec;
 	bool	    qname_wait_recurse;
 	bool	    nsip_wait_recurse;
@@ -184,15 +204,15 @@ struct dns_rpz_popt {
 /*
  * Response policy zones known to a view.
  */
-typedef struct dns_rpz_zones dns_rpz_zones_t;
 struct dns_rpz_zones {
 	dns_rpz_popt_t		p;
 	dns_rpz_zone_t		*zones[DNS_RPZ_MAX_ZONES];
 	dns_rpz_triggers_t	triggers[DNS_RPZ_MAX_ZONES];
 
 	/*
-	 * RPZ policy version number (initially 0, increases whenever
-	 * the server is reconfigured with new zones or policy)
+	 * RPZ policy version number.
+	 * It is initially 0 and it increases whenever the server is
+	 * reconfigured with new zones or policy.
 	 */
 	int			rpz_ver;
 
@@ -223,6 +243,9 @@ struct dns_rpz_zones {
 	dns_rpz_triggers_t	total_triggers;
 
 	isc_mem_t		*mctx;
+	isc_taskmgr_t		*taskmgr;
+	isc_timermgr_t		*timermgr;
+	isc_task_t		*updater;
 	isc_refcount_t		refs;
 	/*
 	 * One lock for short term read-only search that guarantees the
@@ -235,6 +258,13 @@ struct dns_rpz_zones {
 
 	dns_rpz_cidr_node_t	*cidr;
 	dns_rbt_t		*rbt;
+
+	/*
+	 * DNSRPZ librpz configuration string and handle on librpz connection
+	 */
+	char			*rps_cstr;
+	size_t			rps_cstr_size;
+	struct librpz_client	*rps_client;
 };
 
 
@@ -304,6 +334,11 @@ typedef struct {
 	dns_rpz_popt_t		popt;
 	int			rpz_ver;
 
+	/*
+	 * Shim db between BIND and DNRPS librpz.
+	 */
+	dns_db_t		*rpsdb;
+
 	/*
 	 * p_name: current policy owner name
 	 * r_name: recursing for this name to possible policy triggers
@@ -317,8 +352,9 @@ typedef struct {
 	dns_fixedname_t		_fnamef;
 } dns_rpz_st_t;
 
-#define DNS_RPZ_TTL_DEFAULT		5
-#define DNS_RPZ_MAX_TTL_DEFAULT		DNS_RPZ_TTL_DEFAULT
+#define DNS_RPZ_TTL_DEFAULT			5
+#define DNS_RPZ_MAX_TTL_DEFAULT			DNS_RPZ_TTL_DEFAULT
+#define DNS_RPZ_MINUPDATEINTERVAL_DEFAULT	60
 
 /*
  * So various response policy zone messages can be turned up or down.
@@ -344,7 +380,15 @@ dns_rpz_decode_cname(dns_rpz_zone_t *rpz, dns_rdataset_t *rdataset,
 		     dns_name_t *selfname);
 
 isc_result_t
-dns_rpz_new_zones(dns_rpz_zones_t **rpzsp, isc_mem_t *mctx);
+dns_rpz_new_zones(dns_rpz_zones_t **rpzsp, char *rps_cstr,
+		  size_t rps_cstr_size, isc_mem_t *mctx,
+		  isc_taskmgr_t *taskmgr, isc_timermgr_t *timermgr);
+
+isc_result_t
+dns_rpz_new_zone(dns_rpz_zones_t *rpzs, dns_rpz_zone_t **rpzp);
+
+isc_result_t
+dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg);
 
 void
 dns_rpz_attach_rpzs(dns_rpz_zones_t *source, dns_rpz_zones_t **target);
@@ -354,17 +398,21 @@ dns_rpz_detach_rpzs(dns_rpz_zones_t **rpzsp);
 
 isc_result_t
 dns_rpz_beginload(dns_rpz_zones_t **load_rpzsp,
-		  dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num);
+		  dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num)
+	ISC_DEPRECATED;
 
 isc_result_t
 dns_rpz_ready(dns_rpz_zones_t *rpzs,
-	      dns_rpz_zones_t **load_rpzsp, dns_rpz_num_t rpz_num);
+	      dns_rpz_zones_t **load_rpzsp, dns_rpz_num_t rpz_num)
+	ISC_DEPRECATED;
 
 isc_result_t
-dns_rpz_add(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num, dns_name_t *name);
+dns_rpz_add(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
+	    const dns_name_t *name);
 
 void
-dns_rpz_delete(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num, dns_name_t *name);
+dns_rpz_delete(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
+	       const dns_name_t *name);
 
 dns_rpz_num_t
 dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
