@@ -1,23 +1,20 @@
 /*
- * Copyright (C) 2006, 2008-2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id$ */
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/base32.h>
 #include <isc/buffer.h>
 #include <isc/hex.h>
@@ -67,9 +64,9 @@ dns_nsec3_buildrdata(dns_db_t *db, dns_dbversion_t *version,
 	dns_rdataset_t rdataset;
 	isc_region_t r;
 	unsigned int i;
-	isc_boolean_t found;
-	isc_boolean_t found_ns;
-	isc_boolean_t need_rrsig;
+	bool found;
+	bool found_ns;
+	bool need_rrsig;
 
 	unsigned char *nsec_bits, *bm;
 	unsigned int max_type;
@@ -123,7 +120,7 @@ dns_nsec3_buildrdata(dns_db_t *db, dns_dbversion_t *version,
 	result = dns_db_allrdatasets(db, node, version, 0, &rdsiter);
 	if (result != ISC_R_SUCCESS)
 		return (result);
-	found = found_ns = need_rrsig = ISC_FALSE;
+	found = found_ns = need_rrsig = false;
 	for (result = dns_rdatasetiter_first(rdsiter);
 	     result == ISC_R_SUCCESS;
 	     result = dns_rdatasetiter_next(rdsiter))
@@ -146,11 +143,11 @@ dns_nsec3_buildrdata(dns_db_t *db, dns_dbversion_t *version,
 			 */
 			if (rdataset.type == dns_rdatatype_soa ||
 			    rdataset.type == dns_rdatatype_ds)
-				need_rrsig = ISC_TRUE;
+				need_rrsig = true;
 			else if (rdataset.type == dns_rdatatype_ns)
-				found_ns = ISC_TRUE;
+				found_ns = true;
 			else
-				found = ISC_TRUE;
+				found = true;
 		}
 		dns_rdataset_disassociate(&rdataset);
 	}
@@ -185,11 +182,11 @@ dns_nsec3_buildrdata(dns_db_t *db, dns_dbversion_t *version,
 	return (ISC_R_SUCCESS);
 }
 
-isc_boolean_t
+bool
 dns_nsec3_typepresent(dns_rdata_t *rdata, dns_rdatatype_t type) {
 	dns_rdata_nsec3_t nsec3;
 	isc_result_t result;
-	isc_boolean_t present;
+	bool present;
 	unsigned int i, len, window;
 
 	REQUIRE(rdata != NULL);
@@ -199,7 +196,7 @@ dns_nsec3_typepresent(dns_rdata_t *rdata, dns_rdatatype_t type) {
 	result = dns_rdata_tostruct(rdata, &nsec3, NULL);
 	INSIST(result == ISC_R_SUCCESS);
 
-	present = ISC_FALSE;
+	present = false;
 	for (i = 0; i < nsec3.len; i += len) {
 		INSIST(i + 2 <= nsec3.len);
 		window = nsec3.typebits[i];
@@ -212,8 +209,8 @@ dns_nsec3_typepresent(dns_rdata_t *rdata, dns_rdatatype_t type) {
 		if ((window + 1) * 256 <= type)
 			continue;
 		if (type < (window * 256) + len * 8)
-			present = ISC_TF(dns_nsec_isset(&nsec3.typebits[i],
-							type % 256));
+			present = dns_nsec_isset(&nsec3.typebits[i],
+						 type % 256);
 		break;
 	}
 	dns_rdata_freestruct(&nsec3);
@@ -223,7 +220,8 @@ dns_nsec3_typepresent(dns_rdata_t *rdata, dns_rdatatype_t type) {
 isc_result_t
 dns_nsec3_hashname(dns_fixedname_t *result,
 		   unsigned char rethash[NSEC3_MAX_HASH_LENGTH],
-		   size_t *hash_length, dns_name_t *name, dns_name_t *origin,
+		   size_t *hash_length, const dns_name_t *name,
+		   const dns_name_t *origin,
 		   dns_hash_t hashalg, unsigned int iterations,
 		   const unsigned char *salt, size_t saltlength)
 {
@@ -240,8 +238,7 @@ dns_nsec3_hashname(dns_fixedname_t *result,
 
 	memset(rethash, 0, NSEC3_MAX_HASH_LENGTH);
 
-	dns_fixedname_init(&fixed);
-	downcased = dns_fixedname_name(&fixed);
+	downcased = dns_fixedname_initname(&fixed);
 	dns_name_downcase(name, downcased, NULL);
 
 	/* hash the node name */
@@ -276,13 +273,13 @@ dns_nsec3_hashlength(dns_hash_t hash) {
 	return (0);
 }
 
-isc_boolean_t
+bool
 dns_nsec3_supportedhash(dns_hash_t hash) {
 	switch (hash) {
 	case dns_hash_sha1:
-		return (ISC_TRUE);
+		return (true);
 	}
-	return (ISC_FALSE);
+	return (false);
 }
 
 /*%
@@ -331,16 +328,16 @@ do_one_tuple(dns_difftuple_t **tuple, dns_db_t *db, dns_dbversion_t *ver,
  * Set '*exists' to true iff the given name exists, to false otherwise.
  */
 static isc_result_t
-name_exists(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
-	    isc_boolean_t *exists)
+name_exists(dns_db_t *db, dns_dbversion_t *version, const dns_name_t *name,
+	    bool *exists)
 {
 	isc_result_t result;
 	dns_dbnode_t *node = NULL;
 	dns_rdatasetiter_t *iter = NULL;
 
-	result = dns_db_findnode(db, name, ISC_FALSE, &node);
+	result = dns_db_findnode(db, name, false, &node);
 	if (result == ISC_R_NOTFOUND) {
-		*exists = ISC_FALSE;
+		*exists = false;
 		return (ISC_R_SUCCESS);
 	}
 	if (result != ISC_R_SUCCESS)
@@ -353,12 +350,12 @@ name_exists(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 
 	result = dns_rdatasetiter_first(iter);
 	if (result == ISC_R_SUCCESS) {
-		*exists = ISC_TRUE;
+		*exists = true;
 	} else if (result == ISC_R_NOMORE) {
-		*exists = ISC_FALSE;
+		*exists = false;
 		result = ISC_R_SUCCESS;
 	} else
-		*exists = ISC_FALSE;
+		*exists = false;
 	dns_rdatasetiter_destroy(&iter);
 
  cleanup_node:
@@ -366,7 +363,7 @@ name_exists(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 	return (result);
 }
 
-static isc_boolean_t
+static bool
 match_nsec3param(const dns_rdata_nsec3_t *nsec3,
 		 const dns_rdata_nsec3param_t *nsec3param)
 {
@@ -374,8 +371,8 @@ match_nsec3param(const dns_rdata_nsec3_t *nsec3,
 	    nsec3->iterations == nsec3param->iterations &&
 	    nsec3->salt_length == nsec3param->salt_length &&
 	    !memcmp(nsec3->salt, nsec3param->salt, nsec3->salt_length))
-		return (ISC_TRUE);
-	return (ISC_FALSE);
+		return (true);
+	return (false);
 }
 
 /*%
@@ -383,7 +380,7 @@ match_nsec3param(const dns_rdata_nsec3_t *nsec3,
  * change in "diff".
  */
 static isc_result_t
-delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
+delnsec3(dns_db_t *db, dns_dbversion_t *version, const dns_name_t *name,
 	 const dns_rdata_nsec3param_t *nsec3param, dns_diff_t *diff)
 {
 	dns_dbnode_t *node = NULL ;
@@ -392,7 +389,7 @@ delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 	dns_rdataset_t rdataset;
 	isc_result_t result;
 
-	result = dns_db_findnsec3node(db, name, ISC_FALSE, &node);
+	result = dns_db_findnsec3node(db, name, false, &node);
 	if (result == ISC_R_NOTFOUND)
 		return (ISC_R_SUCCESS);
 	if (result != ISC_R_SUCCESS)
@@ -440,13 +437,13 @@ delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 	return (result);
 }
 
-static isc_boolean_t
+static bool
 better_param(dns_rdataset_t *nsec3paramset, dns_rdata_t *param) {
 	dns_rdataset_t rdataset;
 	isc_result_t result;
 
 	if (REMOVE(param->data[1]))
-		return (ISC_TRUE);
+		return (true);
 
 	dns_rdataset_init(&rdataset);
 	dns_rdataset_clone(nsec3paramset, &rdataset);
@@ -476,11 +473,11 @@ better_param(dns_rdataset_t *nsec3paramset, dns_rdata_t *param) {
 			continue;
 		if (CREATE(rdata.data[1]) && !CREATE(param->data[1])) {
 			dns_rdataset_disassociate(&rdataset);
-			return (ISC_TRUE);
+			return (true);
 		}
 	}
 	dns_rdataset_disassociate(&rdataset);
-	return (ISC_FALSE);
+	return (false);
 }
 
 static isc_result_t
@@ -505,8 +502,9 @@ find_nsec3(dns_rdata_nsec3_t *nsec3, dns_rdataset_t *rdataset,
 
 isc_result_t
 dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
-		   dns_name_t *name, const dns_rdata_nsec3param_t *nsec3param,
-		   dns_ttl_t nsecttl, isc_boolean_t unsecure, dns_diff_t *diff)
+		   const dns_name_t *name,
+		   const dns_rdata_nsec3param_t *nsec3param,
+		   dns_ttl_t nsecttl, bool unsecure, dns_diff_t *diff)
 {
 	dns_dbiterator_t *dbit = NULL;
 	dns_dbnode_t *node = NULL;
@@ -523,9 +521,9 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	dns_rdataset_t rdataset;
 	int pass;
-	isc_boolean_t exists = ISC_FALSE;
-	isc_boolean_t maybe_remove_unsecure = ISC_FALSE;
-	isc_uint8_t flags;
+	bool exists = false;
+	bool maybe_remove_unsecure = false;
+	uint8_t flags;
 	isc_buffer_t buffer;
 	isc_result_t result;
 	unsigned char *old_next;
@@ -538,10 +536,8 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 	unsigned int old_length;
 	unsigned int salt_length;
 
-	dns_fixedname_init(&fixed);
-	hashname = dns_fixedname_name(&fixed);
-	dns_fixedname_init(&fprev);
-	prev = dns_fixedname_name(&fprev);
+	hashname = dns_fixedname_initname(&fixed);
+	prev = dns_fixedname_initname(&fprev);
 
 	dns_rdataset_init(&rdataset);
 
@@ -574,7 +570,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 	 * Create the node if it doesn't exist and hold
 	 * a reference to it until we have added the NSEC3.
 	 */
-	CHECK(dns_db_findnsec3node(db, hashname, ISC_TRUE, &newnode));
+	CHECK(dns_db_findnsec3node(db, hashname, true, &newnode));
 
 	/*
 	 * Seek the iterator to the 'newnode'.
@@ -611,7 +607,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 							    nsec3param, diff);
 				goto failure;
 			} else
-				maybe_remove_unsecure = ISC_TRUE;
+				maybe_remove_unsecure = true;
 		} else {
 			dns_rdataset_disassociate(&rdataset);
 			if (result != ISC_R_NOMORE)
@@ -704,7 +700,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 	/*
 	 * Create the NSEC3 RDATA.
 	 */
-	CHECK(dns_db_findnode(db, name, ISC_FALSE, &node));
+	CHECK(dns_db_findnode(db, name, false, &node));
 	CHECK(dns_nsec3_buildrdata(db, version, node, hash, flags, iterations,
 				   salt, salt_length, nexthash, next_length,
 				   nsec3buf, &rdata));
@@ -746,7 +742,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 		 * a reference to it until we have added the NSEC3
 		 * or we discover we don't need to add make a change.
 		 */
-		CHECK(dns_db_findnsec3node(db, hashname, ISC_TRUE, &newnode));
+		CHECK(dns_db_findnsec3node(db, hashname, true, &newnode));
 		result = dns_db_findrdataset(db, newnode, version,
 					     dns_rdatatype_nsec3, 0,
 					     (isc_stdtime_t) 0, &rdataset,
@@ -867,8 +863,8 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
  */
 isc_result_t
 dns_nsec3_addnsec3s(dns_db_t *db, dns_dbversion_t *version,
-		    dns_name_t *name, dns_ttl_t nsecttl,
-		    isc_boolean_t unsecure, dns_diff_t *diff)
+		    const dns_name_t *name, dns_ttl_t nsecttl,
+		    bool unsecure, dns_diff_t *diff)
 {
 	dns_dbnode_t *node = NULL;
 	dns_rdata_nsec3param_t nsec3param;
@@ -924,7 +920,7 @@ dns_nsec3_addnsec3s(dns_db_t *db, dns_dbversion_t *version,
 	return (result);
 }
 
-isc_boolean_t
+bool
 dns_nsec3param_fromprivate(dns_rdata_t *src, dns_rdata_t *target,
 			   unsigned char *buf, size_t buflen)
 {
@@ -938,7 +934,7 @@ dns_nsec3param_fromprivate(dns_rdata_t *src, dns_rdata_t *target,
 	 * NSEC3PARAM records from DNSKEY pointers.
 	 */
 	if (src->length < 1 || src->data[0] != 0)
-		return (ISC_FALSE);
+		return (false);
 
 	isc_buffer_init(&buf1, src->data + 1, src->length - 1);
 	isc_buffer_add(&buf1, src->length - 1);
@@ -950,7 +946,7 @@ dns_nsec3param_fromprivate(dns_rdata_t *src, dns_rdata_t *target,
 				    &buf1, &dctx, 0, &buf2);
 	dns_decompress_invalidate(&dctx);
 
-	return (ISC_TF(result == ISC_R_SUCCESS));
+	return (result == ISC_R_SUCCESS);
 }
 
 void
@@ -973,8 +969,8 @@ dns_nsec3param_toprivate(dns_rdata_t *src, dns_rdata_t *target,
 }
 
 static isc_result_t
-rr_exists(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
-	  const dns_rdata_t *rdata, isc_boolean_t *flag)
+rr_exists(dns_db_t *db, dns_dbversion_t *ver, const dns_name_t *name,
+	  const dns_rdata_t *rdata, bool *flag)
 {
 	dns_rdataset_t rdataset;
 	dns_dbnode_t *node = NULL;
@@ -982,13 +978,13 @@ rr_exists(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 
 	dns_rdataset_init(&rdataset);
 	if (rdata->type == dns_rdatatype_nsec3)
-		CHECK(dns_db_findnsec3node(db, name, ISC_FALSE, &node));
+		CHECK(dns_db_findnsec3node(db, name, false, &node));
 	else
-		CHECK(dns_db_findnode(db, name, ISC_FALSE, &node));
+		CHECK(dns_db_findnode(db, name, false, &node));
 	result = dns_db_findrdataset(db, node, ver, rdata->type, 0,
 				     (isc_stdtime_t) 0, &rdataset, NULL);
 	if (result == ISC_R_NOTFOUND) {
-		*flag = ISC_FALSE;
+		*flag = false;
 		result = ISC_R_SUCCESS;
 		goto failure;
 	}
@@ -1003,9 +999,9 @@ rr_exists(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 	}
 	dns_rdataset_disassociate(&rdataset);
 	if (result == ISC_R_SUCCESS) {
-		*flag = ISC_TRUE;
+		*flag = true;
 	} else if (result == ISC_R_NOMORE) {
-		*flag = ISC_FALSE;
+		*flag = false;
 		result = ISC_R_SUCCESS;
 	}
 
@@ -1053,7 +1049,7 @@ dns_nsec3param_salttotext(dns_rdata_nsec3param_t *nsec3param, char *dst,
 
 isc_result_t
 dns_nsec3param_deletechains(dns_db_t *db, dns_dbversion_t *ver,
-			    dns_zone_t *zone, isc_boolean_t nonsec,
+			    dns_zone_t *zone, bool nonsec,
 			    dns_diff_t *diff)
 {
 	dns_dbnode_t *node = NULL;
@@ -1061,7 +1057,7 @@ dns_nsec3param_deletechains(dns_db_t *db, dns_dbversion_t *ver,
 	dns_name_t next;
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	dns_rdataset_t rdataset;
-	isc_boolean_t flag;
+	bool flag;
 	isc_result_t result = ISC_R_SUCCESS;
 	unsigned char buf[DNS_NSEC3PARAM_BUFFERSIZE + 1];
 	dns_name_t *origin = dns_zone_getorigin(zone);
@@ -1178,8 +1174,8 @@ dns_nsec3param_deletechains(dns_db_t *db, dns_dbversion_t *ver,
 
 isc_result_t
 dns_nsec3_addnsec3sx(dns_db_t *db, dns_dbversion_t *version,
-		     dns_name_t *name, dns_ttl_t nsecttl,
-		     isc_boolean_t unsecure, dns_rdatatype_t type,
+		     const dns_name_t *name, dns_ttl_t nsecttl,
+		     bool unsecure, dns_rdatatype_t type,
 		     dns_diff_t *diff)
 {
 	dns_dbnode_t *node = NULL;
@@ -1283,12 +1279,12 @@ dns_nsec3_addnsec3sx(dns_db_t *db, dns_dbversion_t *version,
 /*%
  * Determine whether any NSEC3 records that were associated with
  * 'name' should be deleted or if they should continue to exist.
- * ISC_TRUE indicates they should be deleted.
- * ISC_FALSE indicates they should be retained.
+ * true indicates they should be deleted.
+ * false indicates they should be retained.
  */
 static isc_result_t
-deleteit(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
-	 isc_boolean_t *yesno)
+deleteit(dns_db_t *db, dns_dbversion_t *ver, const dns_name_t *name,
+	 bool *yesno)
 {
 	isc_result_t result;
 	dns_fixedname_t foundname;
@@ -1301,23 +1297,24 @@ deleteit(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 			     NULL, NULL);
 	if (result == DNS_R_EMPTYNAME || result == ISC_R_SUCCESS ||
 	    result ==  DNS_R_ZONECUT) {
-		*yesno = ISC_FALSE;
+		*yesno = false;
 		return (ISC_R_SUCCESS);
 	}
 	if (result == DNS_R_GLUE || result == DNS_R_DNAME ||
 	    result == DNS_R_DELEGATION || result == DNS_R_NXDOMAIN) {
-		*yesno = ISC_TRUE;
+		*yesno = true;
 		return (ISC_R_SUCCESS);
 	}
 	/*
 	 * Silence compiler.
 	 */
-	*yesno = ISC_TRUE;
+	*yesno = true;
 	return (result);
 }
 
 isc_result_t
-dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
+dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version,
+		   const dns_name_t *name,
 		   const dns_rdata_nsec3param_t *nsec3param, dns_diff_t *diff)
 {
 	dns_dbiterator_t *dbit = NULL;
@@ -1334,7 +1331,7 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	dns_rdataset_t rdataset;
 	int pass;
-	isc_boolean_t yesno;
+	bool yesno;
 	isc_buffer_t buffer;
 	isc_result_t result;
 	unsigned char *salt;
@@ -1345,10 +1342,8 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 	size_t next_length;
 	unsigned int salt_length;
 
-	dns_fixedname_init(&fixed);
-	hashname = dns_fixedname_name(&fixed);
-	dns_fixedname_init(&fprev);
-	prev = dns_fixedname_name(&fprev);
+	hashname = dns_fixedname_initname(&fixed);
+	prev = dns_fixedname_initname(&fprev);
 
 	dns_rdataset_init(&rdataset);
 
@@ -1578,14 +1573,16 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 }
 
 isc_result_t
-dns_nsec3_delnsec3s(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
+dns_nsec3_delnsec3s(dns_db_t *db, dns_dbversion_t *version,
+		    const dns_name_t *name,
 		    dns_diff_t *diff)
 {
 	return (dns_nsec3_delnsec3sx(db, version, name, 0, diff));
 }
 
 isc_result_t
-dns_nsec3_delnsec3sx(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
+dns_nsec3_delnsec3sx(dns_db_t *db, dns_dbversion_t *version,
+		     const dns_name_t *name,
 		     dns_rdatatype_t privatetype, dns_diff_t *diff)
 {
 	dns_dbnode_t *node = NULL;
@@ -1681,15 +1678,15 @@ dns_nsec3_delnsec3sx(dns_db_t *db, dns_dbversion_t *version, dns_name_t *name,
 
 isc_result_t
 dns_nsec3_active(dns_db_t *db, dns_dbversion_t *version,
-		 isc_boolean_t complete, isc_boolean_t *answer)
+		 bool complete, bool *answer)
 {
 	return (dns_nsec3_activex(db, version, complete, 0, answer));
 }
 
 isc_result_t
 dns_nsec3_activex(dns_db_t *db, dns_dbversion_t *version,
-		  isc_boolean_t complete, dns_rdatatype_t privatetype,
-		  isc_boolean_t *answer)
+		  bool complete, dns_rdatatype_t privatetype,
+		  bool *answer)
 {
 	dns_dbnode_t *node = NULL;
 	dns_rdataset_t rdataset;
@@ -1730,15 +1727,15 @@ dns_nsec3_activex(dns_db_t *db, dns_dbversion_t *version,
 	dns_rdataset_disassociate(&rdataset);
 	if (result == ISC_R_SUCCESS) {
 		dns_db_detachnode(db, &node);
-		*answer = ISC_TRUE;
+		*answer = true;
 		return (ISC_R_SUCCESS);
 	}
 	if (result == ISC_R_NOMORE)
-		*answer = ISC_FALSE;
+		*answer = false;
 
  try_private:
 	if (privatetype == 0 || complete) {
-		*answer = ISC_FALSE;
+		*answer = false;
 		return (ISC_R_SUCCESS);
 	}
 	result = dns_db_findrdataset(db, node, version, privatetype, 0, 0,
@@ -1746,7 +1743,7 @@ dns_nsec3_activex(dns_db_t *db, dns_dbversion_t *version,
 
 	dns_db_detachnode(db, &node);
 	if (result == ISC_R_NOTFOUND) {
-		*answer = ISC_FALSE;
+		*answer = false;
 		return (ISC_R_SUCCESS);
 	}
 	if (result != ISC_R_SUCCESS)
@@ -1771,11 +1768,11 @@ dns_nsec3_activex(dns_db_t *db, dns_dbversion_t *version,
 	}
 	dns_rdataset_disassociate(&rdataset);
 	if (result == ISC_R_SUCCESS) {
-		*answer = ISC_TRUE;
+		*answer = true;
 		result = ISC_R_SUCCESS;
 	}
 	if (result == ISC_R_NOMORE) {
-		*answer = ISC_FALSE;
+		*answer = false;
 		result = ISC_R_SUCCESS;
 	}
 
@@ -1812,8 +1809,18 @@ dns_nsec3_maxiterations(dns_db_t *db, dns_dbversion_t *version,
 	     result == ISC_R_SUCCESS;
 	     result = dns_rdataset_next(&rdataset)) {
 		dns_rdata_t rdata = DNS_RDATA_INIT;
-
 		dns_rdataset_current(&rdataset, &rdata);
+
+		REQUIRE(rdata.type == dns_rdatatype_key ||
+			rdata.type == dns_rdatatype_dnskey);
+		REQUIRE(rdata.length > 3);
+
+		/* Skip unsupported algorithms when
+		 * calculating the maximum iterations.
+		 */
+		if (!dst_algorithm_supported(rdata.data[3]))
+			continue;
+
 		isc_buffer_init(&buffer, rdata.data, rdata.length);
 		isc_buffer_add(&buffer, rdata.length);
 		CHECK(dst_key_fromdns(dns_db_origin(db), rdataset.rdclass,
@@ -1841,12 +1848,12 @@ dns_nsec3_maxiterations(dns_db_t *db, dns_dbversion_t *version,
 }
 
 isc_result_t
-dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
-			dns_name_t *nsec3name, dns_rdataset_t *nsec3set,
-			dns_name_t *zonename, isc_boolean_t *exists,
-			isc_boolean_t *data, isc_boolean_t *optout,
-			isc_boolean_t *unknown, isc_boolean_t *setclosest,
-			isc_boolean_t *setnearest, dns_name_t *closest,
+dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
+			const dns_name_t *nsec3name, dns_rdataset_t *nsec3set,
+			dns_name_t *zonename, bool *exists,
+			bool *data, bool *optout,
+			bool *unknown, bool *setclosest,
+			bool *setnearest, dns_name_t *closest,
 			dns_name_t *nearest, dns_nseclog_t logit, void *arg)
 {
 	char namebuf[DNS_NAME_FORMATSIZE];
@@ -1859,10 +1866,10 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	int order;
 	int scope;
-	isc_boolean_t atparent;
-	isc_boolean_t first;
-	isc_boolean_t ns;
-	isc_boolean_t soa;
+	bool atparent;
+	bool first;
+	bool ns;
+	bool soa;
 	isc_buffer_t buffer;
 	isc_result_t answer = ISC_R_IGNORE;
 	isc_result_t result;
@@ -1894,8 +1901,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 
 	(*logit)(arg, ISC_LOG_DEBUG(3), "looking for relevant NSEC3");
 
-	dns_fixedname_init(&fzone);
-	zone = dns_fixedname_name(&fzone);
+	zone = dns_fixedname_initname(&fzone);
 	zlabels = dns_name_countlabels(nsec3name);
 
 	/*
@@ -1938,7 +1944,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 	 */
 	if (!dns_nsec3_supportedhash(nsec3.hash)) {
 		if (unknown != NULL)
-			*unknown = ISC_TRUE;
+			*unknown = true;
 		return (ISC_R_IGNORE);
 	}
 
@@ -1967,11 +1973,10 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 	/*
 	 * Prepare to compute all the hashes.
 	 */
-	dns_fixedname_init(&qfixed);
-	qname = dns_fixedname_name(&qfixed);
+	qname = dns_fixedname_initname(&qfixed);
 	dns_name_downcase(name, qname, NULL);
 	qlabels = dns_name_countlabels(qname);
-	first = ISC_TRUE;
+	first = true;
 
 	while (qlabels >= zlabels) {
 		length = isc_iterated_hash(hash, nsec3.hash, nsec3.iterations,
@@ -2021,7 +2026,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 			    type == dns_rdatatype_nsec ||
 			    type == dns_rdatatype_key ||
 			    !dns_nsec3_typepresent(&rdata, dns_rdatatype_cname)) {
-				*exists = ISC_TRUE;
+				*exists = true;
 				*data = dns_nsec3_typepresent(&rdata, type);
 				(*logit)(arg, ISC_LOG_DEBUG(3),
 					 "NSEC3 proves name exists (owner) "
@@ -2066,7 +2071,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 					 "NSEC3 indicates potential closest "
 					 "encloser: '%s'", namebuf);
 				dns_name_copy(qname, closest, NULL);
-				*setclosest = ISC_TRUE;
+				*setclosest = true;
 			}
 			dns_name_format(qname, namebuf, sizeof(namebuf));
 			(*logit)(arg, ISC_LOG_DEBUG(3),
@@ -2097,20 +2102,18 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 			    (dns_name_countlabels(nearest) == 0 ||
 			     dns_name_issubdomain(nearest, qname))) {
 				dns_name_copy(qname, nearest, NULL);
-				*setnearest = ISC_TRUE;
+				*setnearest = true;
 			}
 
-			*exists = ISC_FALSE;
-			*data = ISC_FALSE;
+			*exists = false;
+			*data = false;
 			if (optout != NULL) {
-				if ((nsec3.flags & DNS_NSEC3FLAG_OPTOUT) != 0)
-					(*logit)(arg, ISC_LOG_DEBUG(3),
-						 "NSEC3 indicates optout");
-				else
-					(*logit)(arg, ISC_LOG_DEBUG(3),
-						 "NSEC3 indicates secure range");
-				*optout =
-				    ISC_TF(nsec3.flags & DNS_NSEC3FLAG_OPTOUT);
+				*optout = ((nsec3.flags & DNS_NSEC3FLAG_OPTOUT)
+					   != 0);
+				(*logit)(arg, ISC_LOG_DEBUG(3),
+					 (*optout
+					  ? "NSEC3 indicates optout"
+					  : "NSEC3 indicates secure range"));
 			}
 			answer = ISC_R_SUCCESS;
 		}
@@ -2118,7 +2121,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, dns_name_t* name,
 		qlabels--;
 		if (qlabels > 0)
 			dns_name_split(qname, qlabels, NULL, qname);
-		first = ISC_FALSE;
+		first = false;
 	}
 	return (answer);
 }
