@@ -1,21 +1,21 @@
 /*
- * Copyright (C) 1999-2005, 2007-2009, 2011-2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*! \file */
 
-/* Principal Authors: DCL */
-
 #include <config.h>
 
 #include <sys/stat.h>
-#ifdef HAVE_INTTYPES_H
 #include <inttypes.h> /* uintptr_t */
-#endif
+#include <stdbool.h>
 
 #include <isc/crc64.h>
 #include <isc/file.h>
@@ -100,16 +100,16 @@ static char FILE_VERSION[32] = "\0";
 
 struct file_header {
 	char version1[32];
-	isc_uint64_t first_node_offset;	/* usually 1024 */
+	uint64_t first_node_offset;	/* usually 1024 */
 	/*
 	 * information about the system on which the map file was generated
 	 * will be used to tell if we can load the map file or not
 	 */
-	isc_uint32_t ptrsize;
+	uint32_t ptrsize;
 	unsigned int bigendian:1;	/* big or little endian system */
 	unsigned int rdataset_fixed:1;	/* compiled with --enable-rrset-fixed */
 	unsigned int nodecount;		/* shadow from rbt structure */
-	isc_uint64_t crc;
+	uint64_t crc;
 	char version2[32];  		/* repeated; must match version1 */
 };
 
@@ -136,21 +136,21 @@ static isc_result_t
 dns_rbt_zero_header(FILE *file);
 
 static isc_result_t
-write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
-	     isc_uint64_t crc);
+write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
+	     uint64_t crc);
 
-static isc_boolean_t
+static bool
 match_header_version(file_header_t *header);
 
 static isc_result_t
 serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	       uintptr_t right, uintptr_t down, uintptr_t parent,
-	       uintptr_t data, isc_uint64_t *crc);
+	       uintptr_t data, uint64_t *crc);
 
 static isc_result_t
 serialize_nodes(FILE *file, dns_rbtnode_t *node, uintptr_t parent,
 		dns_rbtdatawriter_t datawriter, void *writer_arg,
-		uintptr_t *where, isc_uint64_t *crc);
+		uintptr_t *where, uint64_t *crc);
 /*
  * The following functions allow you to get the actual address of a pointer
  * without having to use an if statement to check to see if that address is
@@ -215,8 +215,8 @@ getdata(dns_rbtnode_t *node, file_header_t *header) {
 #define OLDNAMELEN(node)        ((node)->oldnamelen)
 #define OFFSETLEN(node)         ((node)->offsetlen)
 #define ATTRS(node)             ((node)->attributes)
-#define IS_ROOT(node)           ISC_TF((node)->is_root == 1)
-#define FINDCALLBACK(node)      ISC_TF((node)->find_callback == 1)
+#define IS_ROOT(node)           ((node)->is_root == 1)
+#define FINDCALLBACK(node)      ((node)->find_callback == 1)
 
 /*%
  * Structure elements from the rbtdb.c, not
@@ -453,14 +453,14 @@ static isc_result_t
 treefix(dns_rbt_t *rbt, void *base, size_t size,
 	dns_rbtnode_t *n, const dns_name_t *name,
 	dns_rbtdatafixer_t datafixer, void *fixer_arg,
-	isc_uint64_t *crc);
+	uint64_t *crc);
 
 static void
-deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, isc_boolean_t unhash,
+deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, bool unhash,
 	       dns_rbtnode_t **nodep);
 
 static void
-printnodename(dns_rbtnode_t *node, isc_boolean_t quoted, FILE *f);
+printnodename(dns_rbtnode_t *node, bool quoted, FILE *f);
 
 static void
 freenode(dns_rbt_t *rbt, dns_rbtnode_t **nodep);
@@ -507,8 +507,8 @@ init_file_version(void) {
  * here.
  */
 static isc_result_t
-write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
-	     isc_uint64_t crc)
+write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
+	     uint64_t crc)
 {
 	file_header_t header;
 	isc_result_t result;
@@ -520,7 +520,7 @@ write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
 	memmove(header.version1, FILE_VERSION, sizeof(header.version1));
 	memmove(header.version2, FILE_VERSION, sizeof(header.version2));
 	header.first_node_offset = first_node_offset;
-	header.ptrsize = (isc_uint32_t) sizeof(void *);
+	header.ptrsize = (uint32_t) sizeof(void *);
 	header.bigendian = (1 == htonl(1)) ? 1 : 0;
 
 #ifdef DNS_RDATASET_FIXED
@@ -546,7 +546,7 @@ write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
 	return (result);
 }
 
-static isc_boolean_t
+static bool
 match_header_version(file_header_t *header) {
 	RUNTIME_CHECK(isc_once_do(&once, init_file_version) == ISC_R_SUCCESS);
 
@@ -555,16 +555,16 @@ match_header_version(file_header_t *header) {
 	    memcmp(header->version2, FILE_VERSION,
 		   sizeof(header->version1)) != 0)
 	{
-		return (ISC_FALSE);
+		return (false);
 	}
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static isc_result_t
 serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	       uintptr_t right, uintptr_t down, uintptr_t parent,
-	       uintptr_t data, isc_uint64_t *crc)
+	       uintptr_t data, uint64_t *crc)
 {
 	dns_rbtnode_t temp_node;
 	off_t file_position;
@@ -634,9 +634,9 @@ serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	hexdump("node data", node_data, datasize);
 #endif
 
-	isc_crc64_update(crc, (const isc_uint8_t *) &temp_node,
+	isc_crc64_update(crc, (const uint8_t *) &temp_node,
 			 sizeof(dns_rbtnode_t));
-	isc_crc64_update(crc, (const isc_uint8_t *) node_data, datasize);
+	isc_crc64_update(crc, (const uint8_t *) node_data, datasize);
 
  cleanup:
 	return (result);
@@ -645,7 +645,7 @@ serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 static isc_result_t
 serialize_nodes(FILE *file, dns_rbtnode_t *node, uintptr_t parent,
 		dns_rbtdatawriter_t datawriter, void *writer_arg,
-		uintptr_t *where, isc_uint64_t *crc)
+		uintptr_t *where, uint64_t *crc)
 {
 	uintptr_t left = 0, right = 0, down = 0, data = 0;
 	off_t location = 0, offset_adjust;
@@ -722,7 +722,7 @@ dns_rbt_serialize_tree(FILE *file, dns_rbt_t *rbt,
 {
 	isc_result_t result;
 	off_t header_position, node_position, end_position;
-	isc_uint64_t crc;
+	uint64_t crc;
 
 	REQUIRE(file != NULL);
 
@@ -774,7 +774,7 @@ dns_rbt_serialize_tree(FILE *file, dns_rbt_t *rbt,
 static isc_result_t
 treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 	const dns_name_t *name, dns_rbtdatafixer_t datafixer,
-	void *fixer_arg, isc_uint64_t *crc)
+	void *fixer_arg, uint64_t *crc)
 {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_fixedname_t fixed;
@@ -797,8 +797,7 @@ treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 	CONFIRM(dns_name_isvalid(fullname));
 
 	if (!dns_name_isabsolute(&nodename)) {
-		dns_fixedname_init(&fixed);
-		fullname = dns_fixedname_name(&fixed);
+		fullname = dns_fixedname_initname(&fixed);
 		CHECK(dns_name_concatenate(&nodename, name, fullname, NULL));
 	}
 
@@ -875,9 +874,9 @@ treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 		sizeof(dns_rbtnode_t));
 	hexdump("node data", node_data, datasize);
 #endif
-	isc_crc64_update(crc, (const isc_uint8_t *) &header,
+	isc_crc64_update(crc, (const uint8_t *) &header,
 			sizeof(dns_rbtnode_t));
-	isc_crc64_update(crc, (const isc_uint8_t *) node_data,
+	isc_crc64_update(crc, (const uint8_t *) node_data,
 			datasize);
 
  cleanup:
@@ -894,7 +893,7 @@ dns_rbt_deserialize_tree(void *base_address, size_t filesize,
 	isc_result_t result = ISC_R_SUCCESS;
 	file_header_t *header;
 	dns_rbt_t *rbt = NULL;
-	isc_uint64_t crc;
+	uint64_t crc;
 	unsigned int host_big_endian;
 
 	REQUIRE(originp == NULL || *originp == NULL);
@@ -925,7 +924,7 @@ dns_rbt_deserialize_tree(void *base_address, size_t filesize,
 	}
 #endif
 
-	if (header->ptrsize != (isc_uint32_t) sizeof(void *)) {
+	if (header->ptrsize != (uint32_t) sizeof(void *)) {
 		result = ISC_R_INVALIDFILE;
 		goto cleanup;
 	}
@@ -1044,7 +1043,7 @@ dns_rbt_destroy2(dns_rbt_t **rbtp, unsigned int quantum) {
 
 	rbt = *rbtp;
 
-	deletetreeflat(rbt, quantum, ISC_FALSE, &rbt->root);
+	deletetreeflat(rbt, quantum, false, &rbt->root);
 	if (rbt->root != NULL)
 		return (ISC_R_QUOTA);
 
@@ -1081,7 +1080,7 @@ dns_rbt_hashsize(dns_rbt_t *rbt) {
 
 static inline isc_result_t
 chain_name(dns_rbtnodechain_t *chain, dns_name_t *name,
-	   isc_boolean_t include_chain_end)
+	   bool include_chain_end)
 {
 	dns_name_t nodename;
 	isc_result_t result = ISC_R_SUCCESS;
@@ -1188,8 +1187,7 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 	 * Create a copy of the name so the original name structure is
 	 * not modified.
 	 */
-	dns_fixedname_init(&fixedcopy);
-	add_name = dns_fixedname_name(&fixedcopy);
+	add_name = dns_fixedname_initname(&fixedcopy);
 	dns_name_clone(name, add_name);
 
 	if (ISC_UNLIKELY(rbt->root == NULL)) {
@@ -1209,10 +1207,8 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 
 	level_count = 0;
 
-	dns_fixedname_init(&fixedprefix);
-	dns_fixedname_init(&fixedsuffix);
-	prefix = dns_fixedname_name(&fixedprefix);
-	suffix = dns_fixedname_name(&fixedsuffix);
+	prefix = dns_fixedname_initname(&fixedprefix);
+	suffix = dns_fixedname_initname(&fixedsuffix);
 
 	root = &rbt->root;
 	INSIST(IS_ROOT(*root));
@@ -1220,8 +1216,7 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 	current = NULL;
 	child = *root;
 	dns_name_init(&current_name, current_offsets);
-	dns_fixedname_init(&fnewname);
-	new_name = dns_fixedname_name(&fnewname);
+	new_name = dns_fixedname_initname(&fnewname);
 	nlabels = dns_name_countlabels(name);
 	hlabels = 0;
 
@@ -1526,8 +1521,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 	last_compared = NULL;
 	order = 0;
 
-	dns_fixedname_init(&fixedcallbackname);
-	callback_name = dns_fixedname_name(&fixedcallbackname);
+	callback_name = dns_fixedname_initname(&fixedcallbackname);
 
 	/*
 	 * search_name is the name segment being sought in each tree level.
@@ -1536,8 +1530,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 	 * By using dns_name_clone, no name data should be copied thanks to
 	 * the lack of bitstring labels.
 	 */
-	dns_fixedname_init(&fixedsearchname);
-	search_name = dns_fixedname_name(&fixedsearchname);
+	search_name = dns_fixedname_initname(&fixedsearchname);
 	dns_name_clone(name, search_name);
 
 	dns_name_init(&current_name, NULL);
@@ -1612,7 +1605,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 						  nlabels - tlabels,
 						  hlabels + tlabels,
 						  &hash_name);
-			hash = dns_name_fullhash(&hash_name, ISC_FALSE);
+			hash = dns_name_fullhash(&hash_name, false);
 			dns_name_getlabelsequence(search_name,
 						  nlabels - tlabels,
 						  tlabels, &hash_name);
@@ -1740,7 +1733,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 				    FINDCALLBACK(current)) {
 					result = chain_name(chain,
 							    callback_name,
-							    ISC_FALSE);
+							    false);
 					if (result != ISC_R_SUCCESS) {
 						dns_rbtnodechain_reset(chain);
 						return (result);
@@ -1794,7 +1787,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 		chain->level_matches = chain->level_count;
 
 		if (foundname != NULL)
-			result = chain_name(chain, foundname, ISC_TRUE);
+			result = chain_name(chain, foundname, true);
 		else
 			result = ISC_R_SUCCESS;
 
@@ -1831,7 +1824,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 				chain->level_count = chain->level_matches + 1;
 
 				result = chain_name(chain, foundname,
-						    ISC_FALSE);
+						    false);
 
 				chain->level_count = saved_count;
 			} else
@@ -2037,7 +2030,7 @@ dns_rbt_findname(dns_rbt_t *rbt, const dns_name_t *name, unsigned int options,
  */
 isc_result_t
 dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name,
-		   isc_boolean_t recurse)
+		   bool recurse)
 {
 	dns_rbtnode_t *node = NULL;
 	isc_result_t result;
@@ -2111,7 +2104,7 @@ dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name,
  * succeeds. It still returns isc_result_t, though, so the API wouldn't change.
  */
 isc_result_t
-dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, isc_boolean_t recurse)
+dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, bool recurse)
 {
 	dns_rbtnode_t *parent;
 
@@ -2122,7 +2115,7 @@ dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, isc_boolean_t recurse)
 	if (DOWN(node) != NULL) {
 		if (recurse) {
 			PARENT(DOWN(node)) = NULL;
-			deletetreeflat(rbt, 0, ISC_TRUE, &DOWN(node));
+			deletetreeflat(rbt, 0, true, &DOWN(node));
 		} else {
 			if (DATA(node) != NULL && rbt->data_deleter != NULL)
 				rbt->data_deleter(DATA(node), rbt->deleter_arg);
@@ -2218,8 +2211,7 @@ dns_rbt_formatnodename(dns_rbtnode_t *node, char *printname, unsigned int size)
 	REQUIRE(DNS_RBTNODE_VALID(node));
 	REQUIRE(printname != NULL);
 
-	dns_fixedname_init(&fixedname);
-	name = dns_fixedname_name(&fixedname);
+	name = dns_fixedname_initname(&fixedname);
 	result = dns_rbt_fullnamefromnode(node, name);
 	if (result == ISC_R_SUCCESS)
 		dns_name_format(name, printname, size);
@@ -2318,7 +2310,7 @@ hash_add_node(dns_rbt_t *rbt, dns_rbtnode_t *node, const dns_name_t *name) {
 
 	REQUIRE(name != NULL);
 
-	HASHVAL(node) = dns_name_fullhash(name, ISC_FALSE);
+	HASHVAL(node) = dns_name_fullhash(name, false);
 
 	hash = HASHVAL(node) % rbt->hashsize;
 	HASHNEXT(node) = rbt->hashtable[hash];
@@ -2663,8 +2655,8 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 		if (IS_ROOT(item)) {
 			*rootp = successor;
-			successor->is_root = ISC_TRUE;
-			item->is_root = ISC_FALSE;
+			successor->is_root = true;
+			item->is_root = false;
 
 		} else
 			if (LEFT(PARENT(item)) == item)
@@ -2834,7 +2826,7 @@ freenode(dns_rbt_t *rbt, dns_rbtnode_t **nodep) {
 }
 
 static void
-deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, isc_boolean_t unhash,
+deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, bool unhash,
 	       dns_rbtnode_t **nodep)
 {
 	dns_rbtnode_t *root = *nodep;
@@ -2907,31 +2899,31 @@ dns__rbt_getheight(dns_rbt_t *rbt) {
 	return (getheight_helper(rbt->root));
 }
 
-static isc_boolean_t
+static bool
 check_properties_helper(dns_rbtnode_t *node) {
 	if (node == NULL)
-		return (ISC_TRUE);
+		return (true);
 
 	if (IS_RED(node)) {
 		/* Root nodes must be BLACK. */
 		if (IS_ROOT(node))
-			return (ISC_FALSE);
+			return (false);
 
 		/* Both children of RED nodes must be BLACK. */
 		if (IS_RED(LEFT(node)) || IS_RED(RIGHT(node)))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	if ((DOWN(node) != NULL) && (!IS_ROOT(DOWN(node))))
-		return (ISC_FALSE);
+		return (false);
 
 	if (IS_ROOT(node)) {
 		if ((PARENT(node) != NULL) &&
 		    (DOWN(PARENT(node)) != node))
-			return (ISC_FALSE);
+			return (false);
 
 		if (get_upper_node(node) != PARENT(node))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	/* If node is assigned to the down_ pointer of its parent, it is
@@ -2941,7 +2933,7 @@ check_properties_helper(dns_rbtnode_t *node) {
 	     (DOWN(PARENT(node)) == node)) &&
 	    (!IS_ROOT(node)))
 	{
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	/* Repeat tests with this node's children. */
@@ -2950,42 +2942,42 @@ check_properties_helper(dns_rbtnode_t *node) {
 		check_properties_helper(DOWN(node)));
 }
 
-static isc_boolean_t
+static bool
 check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 	size_t dl, dr, dd;
 
 	if (node == NULL) {
 		*distance = 1;
-		return (ISC_TRUE);
+		return (true);
 	}
 
 	if (!check_black_distance_helper(LEFT(node), &dl))
-		return (ISC_FALSE);
+		return (false);
 
 	if (!check_black_distance_helper(RIGHT(node), &dr))
-		return (ISC_FALSE);
+		return (false);
 
 	if (!check_black_distance_helper(DOWN(node), &dd))
-		return (ISC_FALSE);
+		return (false);
 
 	/* Left and right side black node counts must match. */
 	if (dl != dr)
-		return (ISC_FALSE);
+		return (false);
 
 	if (IS_BLACK(node))
 		dl++;
 
 	*distance = dl;
 
-	return (ISC_TRUE);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dns__rbt_checkproperties(dns_rbt_t *rbt) {
 	size_t dd;
 
 	if (!check_properties_helper(rbt->root))
-		return (ISC_FALSE);
+		return (false);
 
 	/* Path from a given node to all its leaves must contain the
 	 * same number of BLACK child nodes. This is done separately
@@ -3008,7 +3000,7 @@ dns_rbt_indent(FILE *f, int depth) {
 void
 dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 	fprintf(f, "Node info for nodename: ");
-	printnodename(n, ISC_TRUE, f);
+	printnodename(n, true, f);
 	fprintf(f, "\n");
 
 	fprintf(f, "n = %p\n", n);
@@ -3020,7 +3012,7 @@ dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 			(n->down_is_relative == 1 ? " D" : ""),
 			(n->data_is_relative == 1 ? " T" : ""));
 
-	fprintf(f, "node lock address = %d\n", n->locknum);
+	fprintf(f, "node lock address = %u\n", n->locknum);
 
 	fprintf(f, "Parent: %p\n", n->parent);
 	fprintf(f, "Right: %p\n", n->right);
@@ -3030,7 +3022,7 @@ dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 }
 
 static void
-printnodename(dns_rbtnode_t *node, isc_boolean_t quoted, FILE *f) {
+printnodename(dns_rbtnode_t *node, bool quoted, FILE *f) {
 	isc_region_t r;
 	dns_name_t name;
 	char buffer[DNS_NAME_FORMATSIZE];
@@ -3058,7 +3050,7 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 	dns_rbt_indent(f, depth);
 
 	if (root != NULL) {
-		printnodename(root, ISC_TRUE, f);
+		printnodename(root, true, f);
 		fprintf(f, " (%s, %s", direction,
 			IS_RED(root) ? "RED" : "BLACK");
 
@@ -3068,7 +3060,7 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 
 			fprintf(f, " (BAD parent pointer! -> ");
 			if (PARENT(root) != NULL)
-				printnodename(PARENT(root), ISC_TRUE, f);
+				printnodename(PARENT(root), true, f);
 			else
 				fprintf(f, "NULL");
 			fprintf(f, ")");
@@ -3112,7 +3104,7 @@ dns_rbt_printtext(dns_rbt_t *rbt,
 
 static int
 print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
-		 isc_boolean_t show_pointers, FILE *f)
+		 bool show_pointers, FILE *f)
 {
 	unsigned int l, r, d;
 
@@ -3126,7 +3118,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 	*nodecount += 1;
 
 	fprintf(f, "node%u[label = \"<f0> |<f1> ", *nodecount);
-	printnodename(node, ISC_FALSE, f);
+	printnodename(node, false, f);
 	fprintf(f, "|<f2>");
 
 	if (show_pointers)
@@ -3164,7 +3156,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 }
 
 void
-dns_rbt_printdot(dns_rbt_t *rbt, isc_boolean_t show_pointers, FILE *f) {
+dns_rbt_printdot(dns_rbt_t *rbt, bool show_pointers, FILE *f) {
 	unsigned int nodecount = 0;
 
 	REQUIRE(VALID_RBT(rbt));
@@ -3231,7 +3223,7 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 	if (origin != NULL) {
 		if (chain->level_count > 0)
-			result = chain_name(chain, origin, ISC_FALSE);
+			result = chain_name(chain, origin, false);
 		else
 			result = dns_name_copy(dns_rootname, origin, NULL);
 	}
@@ -3245,7 +3237,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *previous, *predecessor;
 	isc_result_t result = ISC_R_SUCCESS;
-	isc_boolean_t new_origin = ISC_FALSE;
+	bool new_origin = false;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3313,7 +3305,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 			/* XXX DCL probably needs work on the concept */
 			if (origin != NULL)
-				new_origin = ISC_TRUE;
+				new_origin = true;
 		}
 
 	} else if (chain->level_count > 0) {
@@ -3334,7 +3326,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (origin != NULL &&
 		    (chain->level_count > 0 || OFFSETLEN(predecessor) > 1))
-			new_origin = ISC_TRUE;
+			new_origin = true;
 	}
 
 	if (predecessor != NULL) {
@@ -3362,7 +3354,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *successor;
 	isc_result_t result = ISC_R_SUCCESS;
-	isc_boolean_t new_origin = ISC_FALSE;
+	bool new_origin = false;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3378,7 +3370,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (chain->level_count > 0 ||
 		    OFFSETLEN(current) > 1)
-			new_origin = ISC_TRUE;
+			new_origin = true;
 
 		ADD_LEVEL(chain, current);
 		current = DOWN(current);
@@ -3406,7 +3398,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 		if (new_origin) {
 			if (origin != NULL)
-				result = chain_name(chain, origin, ISC_FALSE);
+				result = chain_name(chain, origin, false);
 
 			if (result == ISC_R_SUCCESS)
 				result = DNS_R_NEWORIGIN;
@@ -3469,7 +3461,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *previous, *successor;
 	isc_result_t result = ISC_R_SUCCESS;
-	isc_boolean_t new_origin = ISC_FALSE;
+	bool new_origin = false;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3489,7 +3481,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (chain->level_count > 0 ||
 		    OFFSETLEN(current) > 1)
-			new_origin = ISC_TRUE;
+			new_origin = true;
 
 		ADD_LEVEL(chain, current);
 		current = DOWN(current);
@@ -3544,7 +3536,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 				}
 
 				current = chain->levels[--chain->level_count];
-				new_origin = ISC_TRUE;
+				new_origin = true;
 
 				if (RIGHT(current) != NULL)
 					break;
@@ -3584,7 +3576,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 		if (new_origin) {
 			if (origin != NULL)
-				result = chain_name(chain, origin, ISC_FALSE);
+				result = chain_name(chain, origin, false);
 
 			if (result == ISC_R_SUCCESS)
 				result = DNS_R_NEWORIGIN;
