@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -17,10 +17,9 @@
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdbool.h>
-#include <stdio.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <unistd.h>
 
@@ -79,11 +78,11 @@ dns_acl_isinsecure_test(void **state) {
 	dns_acl_t *none = NULL;
 	dns_acl_t *notnone = NULL;
 	dns_acl_t *notany = NULL;
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 	dns_acl_t *geoip = NULL;
 	dns_acl_t *notgeoip = NULL;
 	dns_aclelement_t *de;
-#endif /* HAVE_GEOIP || HAVE_GEOIP2 */
+#endif
 	dns_acl_t *pos4pos6 = NULL;
 	dns_acl_t *notpos4pos6 = NULL;
 	dns_acl_t *neg4pos6 = NULL;
@@ -127,7 +126,7 @@ dns_acl_isinsecure_test(void **state) {
 	result = dns_acl_merge(notany, any, false);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 	result = dns_acl_create(mctx, 1, &geoip);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
@@ -139,8 +138,8 @@ dns_acl_isinsecure_test(void **state) {
 	de->type = dns_aclelementtype_geoip;
 	de->negative = false;
 	assert_true(geoip->length < geoip->alloc);
-	dns_acl_node_count(geoip)++;
-	de->node_num = dns_acl_node_count(geoip);
+	geoip->node_count++;
+	de->node_num = geoip->node_count;
 	geoip->length++;
 
 	result = dns_acl_create(mctx, 1, &notgeoip);
@@ -148,26 +147,26 @@ dns_acl_isinsecure_test(void **state) {
 
 	result = dns_acl_merge(notgeoip, geoip, false);
 	assert_int_equal(result, ISC_R_SUCCESS);
-#endif /* HAVE_GEOIP || HAVE_GEOIP2 */
+#endif
 
 	assert_true(dns_acl_isinsecure(any));		/* any; */
 	assert_false(dns_acl_isinsecure(none));		/* none; */
 	assert_false(dns_acl_isinsecure(notany));	/* !any; */
 	assert_false(dns_acl_isinsecure(notnone));	/* !none; */
 
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 	assert_true(dns_acl_isinsecure(geoip));		/* geoip; */
 	assert_false(dns_acl_isinsecure(notgeoip));	/* !geoip; */
-#endif /* HAVE_GEOIP || HAVE_GEOIP2 */
+#endif
 
 	dns_acl_detach(&any);
 	dns_acl_detach(&none);
 	dns_acl_detach(&notany);
 	dns_acl_detach(&notnone);
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 	dns_acl_detach(&geoip);
 	dns_acl_detach(&notgeoip);
-#endif /* HAVE_GEOIP || HAVE_GEOIP2 */
+#endif
 
 	for (pass = 0; pass < sizeof(ecs)/sizeof(ecs[0]); pass++) {
 		result = dns_acl_create(mctx, 1, &pos4pos6);
@@ -390,7 +389,7 @@ main(void) {
 						_setup, _teardown),
 	};
 
-	return (cmocka_run_group_tests(tests, dns_test_init, dns_test_final));
+	return (cmocka_run_group_tests(tests, NULL, NULL));
 }
 
 #else /* HAVE_CMOCKA */
