@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -59,22 +59,12 @@ extern bool app_running;
 extern int ncpus;
 extern bool debug_mem_record;
 
-/* Run once before all tests */
-int
-dns_test_init(void **);
-
-/* Can be run before each test case */
 isc_result_t
 dns_test_begin(FILE *logfile, bool create_managers);
 
-/* Can be after each test case */
 void
 dns_test_end(void);
 
-/* Run once after all tests */
-int
-dns_test_final(void **);
-
 isc_result_t
 dns_test_makeview(const char *name, dns_view_t **viewp);
 
