@@ -135,7 +135,7 @@ main(void) {
 		cmocka_unit_test_setup_teardown(trimttl, _setup, _teardown),
 	};
 
-	return (cmocka_run_group_tests(tests, dns_test_init, dns_test_final));
+	return (cmocka_run_group_tests(tests, NULL, NULL));
 }
 
 #else /* HAVE_CMOCKA */
