@@ -17,7 +17,6 @@
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
@@ -28,7 +27,6 @@
 
 #include <isc/app.h>
 #include <isc/buffer.h>
-#include <isc/mutex.h>
 #include <isc/print.h>
 #include <isc/task.h>
 #include <isc/timer.h>
@@ -42,8 +40,6 @@
 
 #include "dnstest.h"
 
-static isc_mutex_t done_lock;
-
 struct args {
 	void *arg1;
 	void *arg2;
@@ -89,9 +85,7 @@ load_done(dns_zt_t *zt, dns_zone_t *zone, isc_task_t *task) {
 	UNUSED(zone);
 	UNUSED(task);
 
-	LOCK(&done_lock);
 	*done = true;
-	UNLOCK(&done_lock);
 	isc_app_shutdown();
 	return (ISC_R_SUCCESS);
 }
@@ -100,9 +94,7 @@ static isc_result_t
 all_done(void *arg) {
 	bool *done = (bool *) arg;
 
-	LOCK(&done_lock);
 	*done = true;
-	UNLOCK(&done_lock);
 	isc_app_shutdown();
 	return (ISC_R_SUCCESS);
 }
@@ -178,9 +170,6 @@ asyncload_zone(void **state) {
 
 	UNUSED(state);
 
-	result = isc_mutex_init(&done_lock);
-	assert_int_equal(result, ISC_R_SUCCESS);
-
 	result = dns_test_makezone("foo", &zone, NULL, true);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
@@ -193,9 +182,7 @@ asyncload_zone(void **state) {
 	assert_non_null(view->zonetable);
 
 	assert_false(dns__zone_loadpending(zone));
-	LOCK(&done_lock);
 	assert_false(done);
-	UNLOCK(&done_lock);
 	zonefile = fopen("./zone.data", "wb");
 	assert_non_null(zonefile);
 	origfile = fopen("./testdata/zt/zone1.db", "r+b");
@@ -215,9 +202,7 @@ asyncload_zone(void **state) {
 	isc_app_run();
 	while (dns__zone_loadpending(zone) && i++ < 5000)
 		dns_test_nap(1000);
-	LOCK(&done_lock);
 	assert_true(done);
-	UNLOCK(&done_lock);
 	/* The zone should now be loaded; test it */
 	result = dns_zone_getdb(zone, &db);
 	assert_int_equal(result, ISC_R_SUCCESS);
@@ -239,9 +224,7 @@ asyncload_zone(void **state) {
 
 	while (dns__zone_loadpending(zone) && i++ < 5000)
 		dns_test_nap(1000);
-	LOCK(&done_lock);
 	assert_true(done);
-	UNLOCK(&done_lock);
 	/* The zone should now be loaded; test it */
 	result = dns_zone_getdb(zone, &db);
 	assert_int_equal(result, ISC_R_SUCCESS);
@@ -257,9 +240,7 @@ asyncload_zone(void **state) {
 
 	while (dns__zone_loadpending(zone) && i++ < 5000)
 		dns_test_nap(1000);
-	LOCK(&done_lock);
 	assert_true(done);
-	UNLOCK(&done_lock);
 	/* The zone should now be loaded; test it */
 	result = dns_zone_getdb(zone, &db);
 	assert_int_equal(result, ISC_R_SUCCESS);
@@ -273,9 +254,6 @@ asyncload_zone(void **state) {
 
 	dns_zone_detach(&zone);
 	dns_view_detach(&view);
-
-	result = isc_mutex_destroy(&done_lock);
-	assert_int_equal(result, ISC_R_SUCCESS);
 }
 
 /* asynchronous zone table load */
@@ -292,9 +270,6 @@ asyncload_zt(void **state) {
 
 	UNUSED(state);
 
-	result = isc_mutex_init(&done_lock);
-	assert_int_equal(result, ISC_R_SUCCESS);
-
 	result = dns_test_makezone("foo", &zone1, NULL, true);
 	assert_int_equal(result, ISC_R_SUCCESS);
 	dns_zone_setfile(zone1, "testdata/zt/zone1.db");
@@ -323,23 +298,16 @@ asyncload_zt(void **state) {
 
 	assert_false(dns__zone_loadpending(zone1));
 	assert_false(dns__zone_loadpending(zone2));
-	LOCK(&done_lock);
 	assert_false(done);
-	UNLOCK(&done_lock);
 
 	args.arg1 = zt;
 	args.arg2 = &done;
 	isc_app_onrun(mctx, maintask, start_zt_asyncload, &args);
 
 	isc_app_run();
-	LOCK(&done_lock);
-	while (!done && i++ < 5000) {
-		UNLOCK(&done_lock);
+	while (!done && i++ < 5000)
 		dns_test_nap(1000);
-		LOCK(&done_lock);
-	}
 	assert_true(done);
-	UNLOCK(&done_lock);
 
 	/* Both zones should now be loaded; test them */
 	result = dns_zone_getdb(zone1, &db);
@@ -363,9 +331,6 @@ asyncload_zt(void **state) {
 	dns_zone_detach(&zone2);
 	dns_zone_detach(&zone3);
 	dns_view_detach(&view);
-
-	result = isc_mutex_destroy(&done_lock);
-	assert_int_equal(result, ISC_R_SUCCESS);
 }
 
 int
@@ -378,7 +343,7 @@ main(void) {
 						_setup, _teardown),
 	};
 
-	return (cmocka_run_group_tests(tests, dns_test_init, dns_test_final));
+	return (cmocka_run_group_tests(tests, NULL, NULL));
 }
 
 #else /* HAVE_CMOCKA */
