@@ -31,7 +31,6 @@
 #include <isc/task.h>
 #include <isc/util.h>
 
-#include <dns/acache.h>
 #include <dns/acl.h>
 #include <dns/adb.h>
 #include <dns/badcache.h>
@@ -144,7 +143,6 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 		goto cleanup_zt;
 	}
 
-	view->acache = NULL;
 	view->cache = NULL;
 	view->cachedb = NULL;
 	ISC_LIST_INIT(view->dlz_searched);
@@ -157,13 +155,9 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 	view->frozen = false;
 	view->task = NULL;
 	result = isc_refcount_init(&view->references, 1);
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		goto cleanup_fwdtable;
-	}
-	result = isc_refcount_init(&view->weakrefs, 1);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_references;
-	}
+	view->weakrefs = 0;
 	view->attributes = (DNS_VIEWATTR_RESSHUTDOWN|DNS_VIEWATTR_ADBSHUTDOWN|
 			    DNS_VIEWATTR_REQSHUTDOWN);
 	view->statickeys = NULL;
@@ -173,7 +167,7 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 	view->matchrecursiveonly = false;
 	result = dns_tsigkeyring_create(view->mctx, &view->dynamickeys);
 	if (result != ISC_R_SUCCESS)
-		goto cleanup_weakrefs;
+		goto cleanup_references;
 	view->peers = NULL;
 	view->order = NULL;
 	view->delonly = NULL;
@@ -191,11 +185,10 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 	 */
 	view->recursion = true;
 	view->auth_nxdomain = false; /* Was true in BIND 8 */
-	view->additionalfromcache = true;
-	view->additionalfromauth = true;
 	view->enablednssec = true;
 	view->enablevalidation = true;
 	view->acceptexpired = false;
+	view->use_glue_cache = false;
 	view->minimal_any = false;
 	view->minimalresponses = dns_minimal_no;
 	view->transfer_format = dns_one_answer;
@@ -229,7 +222,12 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 	view->flush = false;
 	view->dlv = NULL;
 	view->maxudp = 0;
+	view->staleanswerttl = 1;
+	view->staleanswersok = dns_stale_answer_conf;
+	view->staleanswersenable = false;
 	view->nocookieudp = 0;
+	view->padding = 0;
+	view->pad_acl = NULL;
 	view->maxbits = 0;
 	view->v4_aaaa = dns_aaaa_ok;
 	view->v6_aaaa = dns_aaaa_ok;
@@ -244,8 +242,10 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 	view->requestnsid = false;
 	view->sendcookie = true;
 	view->requireservercookie = false;
+	view->synthfromdnssec = true;
 	view->trust_anchor_telemetry = true;
 	view->root_key_sentinel = true;
+	view->new_zone_dir = NULL;
 	view->new_zone_file = NULL;
 	view->new_zone_db = NULL;
 	view->new_zone_dbenv = NULL;
@@ -322,10 +322,6 @@ dns_view_create(isc_mem_t *mctx, dns_rdataclass_t rdclass,
 		dns_tsigkeyring_detach(&view->dynamickeys);
 	}
 
- cleanup_weakrefs:
-	isc_refcount_decrement(&view->weakrefs, NULL);
-	isc_refcount_destroy(&view->weakrefs);
-
  cleanup_references:
 	isc_refcount_decrement(&view->references, NULL);
 	isc_refcount_destroy(&view->references);
@@ -362,13 +358,12 @@ destroy(dns_view_t *view) {
 	dns_dlzdb_t *dlzdb;
 
 	REQUIRE(!ISC_LINK_LINKED(view, link));
+	REQUIRE(isc_refcount_current(&view->references) == 0);
+	REQUIRE(view->weakrefs == 0);
 	REQUIRE(RESSHUTDOWN(view));
 	REQUIRE(ADBSHUTDOWN(view));
 	REQUIRE(REQSHUTDOWN(view));
 
-	isc_refcount_destroy(&view->references);
-	isc_refcount_destroy(&view->weakrefs);
-
 	if (view->order != NULL)
 		dns_order_detach(&view->order);
 	if (view->peers != NULL)
@@ -412,11 +407,6 @@ destroy(dns_view_t *view) {
 		dns_adb_detach(&view->adb);
 	if (view->resolver != NULL)
 		dns_resolver_detach(&view->resolver);
-	if (view->acache != NULL) {
-		if (view->cachedb != NULL)
-			dns_acache_putdb(view->acache, view->cachedb);
-		dns_acache_detach(&view->acache);
-	}
 	dns_rrl_view_destroy(view);
 	if (view->rpzs != NULL)
 		dns_rpz_detach_rpzs(&view->rpzs);
@@ -476,6 +466,8 @@ destroy(dns_view_t *view) {
 		dns_acl_detach(&view->denyansweracl);
 	if (view->aaaa_acl != NULL)
 		dns_acl_detach(&view->aaaa_acl);
+	if (view->pad_acl != NULL)
+		dns_acl_detach(&view->pad_acl);
 	if (view->answeracl_exclude != NULL)
 		dns_rbt_destroy(&view->answeracl_exclude);
 	if (view->denyanswernames != NULL)
@@ -546,6 +538,10 @@ destroy(dns_view_t *view) {
 		isc_mem_free(view->mctx, view->new_zone_file);
 		view->new_zone_file = NULL;
 	}
+	if (view->new_zone_dir != NULL) {
+		isc_mem_free(view->mctx, view->new_zone_dir);
+		view->new_zone_dir = NULL;
+	}
 #ifdef HAVE_LMDB
 	if (view->new_zone_dbenv != NULL) {
 		mdb_env_close((MDB_env *) view->new_zone_dbenv);
@@ -563,12 +559,26 @@ destroy(dns_view_t *view) {
 	DESTROYLOCK(&view->new_zone_lock);
 	DESTROYLOCK(&view->lock);
 	isc_refcount_destroy(&view->references);
-	isc_refcount_destroy(&view->weakrefs);
 	isc_mem_free(view->mctx, view->nta_file);
 	isc_mem_free(view->mctx, view->name);
 	isc_mem_putanddetach(&view->mctx, view, sizeof(*view));
 }
 
+/*
+ * Return true iff 'view' may be freed.
+ * The caller must be holding the view lock.
+ */
+static bool
+all_done(dns_view_t *view) {
+
+	if (isc_refcount_current(&view->references) == 0 &&
+	    view->weakrefs == 0 &&
+	    RESSHUTDOWN(view) && ADBSHUTDOWN(view) && REQSHUTDOWN(view))
+		return (true);
+
+	return (false);
+}
+
 void
 dns_view_attach(dns_view_t *source, dns_view_t **targetp) {
 
@@ -584,10 +594,10 @@ static void
 view_flushanddetach(dns_view_t **viewp, bool flush) {
 	dns_view_t *view;
 	unsigned int refs;
+	bool done = false;
 
 	REQUIRE(viewp != NULL);
 	view = *viewp;
-	*viewp = NULL;
 	REQUIRE(DNS_VIEW_VALID(view));
 
 	if (flush)
@@ -603,8 +613,6 @@ view_flushanddetach(dns_view_t **viewp, bool flush) {
 			dns_adb_shutdown(view->adb);
 		if (!REQSHUTDOWN(view))
 			dns_requestmgr_shutdown(view->requestmgr);
-		if (view->acache != NULL)
-			dns_acache_shutdown(view->acache);
 		if (view->zonetable != NULL) {
 			if (view->flush)
 				dns_zt_flushanddetach(&view->zonetable);
@@ -626,9 +634,7 @@ view_flushanddetach(dns_view_t **viewp, bool flush) {
 		if (view->catzs != NULL) {
 			dns_catz_catzs_detach(&view->catzs);
 		}
-		if (view->ntatable_priv != NULL) {
-			dns_ntatable_shutdown(view->ntatable_priv);
-		}
+		done = all_done(view);
 		UNLOCK(&view->lock);
 
 		/* Need to detach zones outside view lock */
@@ -637,9 +643,12 @@ view_flushanddetach(dns_view_t **viewp, bool flush) {
 
 		if (rdzone != NULL)
 			dns_zone_detach(&rdzone);
-
-		dns_view_weakdetach(&view);
 	}
+
+	*viewp = NULL;
+
+	if (done)
+		destroy(view);
 }
 
 void
@@ -673,7 +682,9 @@ dns_view_weakattach(dns_view_t *source, dns_view_t **targetp) {
 	REQUIRE(DNS_VIEW_VALID(source));
 	REQUIRE(targetp != NULL && *targetp == NULL);
 
-	isc_refcount_increment(&source->weakrefs, NULL);
+	LOCK(&source->lock);
+	source->weakrefs++;
+	UNLOCK(&source->lock);
 
 	*targetp = source;
 }
@@ -681,22 +692,30 @@ dns_view_weakattach(dns_view_t *source, dns_view_t **targetp) {
 void
 dns_view_weakdetach(dns_view_t **viewp) {
 	dns_view_t *view;
-	unsigned int weakrefs;
+	bool done = false;
 
 	REQUIRE(viewp != NULL);
 	view = *viewp;
 	REQUIRE(DNS_VIEW_VALID(view));
+
+	LOCK(&view->lock);
+
+	INSIST(view->weakrefs > 0);
+	view->weakrefs--;
+	done = all_done(view);
+
+	UNLOCK(&view->lock);
+
 	*viewp = NULL;
 
-	isc_refcount_decrement(&view->weakrefs, &weakrefs);
-	if (weakrefs == 0) {
+	if (done)
 		destroy(view);
-	}
 }
 
 static void
 resolver_shutdown(isc_task_t *task, isc_event_t *event) {
 	dns_view_t *view = event->ev_arg;
+	bool done;
 
 	REQUIRE(event->ev_type == DNS_EVENT_VIEWRESSHUTDOWN);
 	REQUIRE(DNS_VIEW_VALID(view));
@@ -707,15 +726,20 @@ resolver_shutdown(isc_task_t *task, isc_event_t *event) {
 	isc_event_free(&event);
 
 	LOCK(&view->lock);
+
 	view->attributes |= DNS_VIEWATTR_RESSHUTDOWN;
+	done = all_done(view);
+
 	UNLOCK(&view->lock);
 
-	dns_view_weakdetach(&view);
+	if (done)
+		destroy(view);
 }
 
 static void
 adb_shutdown(isc_task_t *task, isc_event_t *event) {
 	dns_view_t *view = event->ev_arg;
+	bool done;
 
 	REQUIRE(event->ev_type == DNS_EVENT_VIEWADBSHUTDOWN);
 	REQUIRE(DNS_VIEW_VALID(view));
@@ -726,15 +750,20 @@ adb_shutdown(isc_task_t *task, isc_event_t *event) {
 	isc_event_free(&event);
 
 	LOCK(&view->lock);
+
 	view->attributes |= DNS_VIEWATTR_ADBSHUTDOWN;
+	done = all_done(view);
+
 	UNLOCK(&view->lock);
 
-	dns_view_weakdetach(&view);
+	if (done)
+		destroy(view);
 }
 
 static void
 req_shutdown(isc_task_t *task, isc_event_t *event) {
 	dns_view_t *view = event->ev_arg;
+	bool done;
 
 	REQUIRE(event->ev_type == DNS_EVENT_VIEWREQSHUTDOWN);
 	REQUIRE(DNS_VIEW_VALID(view));
@@ -745,10 +774,14 @@ req_shutdown(isc_task_t *task, isc_event_t *event) {
 	isc_event_free(&event);
 
 	LOCK(&view->lock);
+
 	view->attributes |= DNS_VIEWATTR_REQSHUTDOWN;
+	done = all_done(view);
+
 	UNLOCK(&view->lock);
 
-	dns_view_weakdetach(&view);
+	if (done)
+		destroy(view);
 }
 
 isc_result_t
@@ -797,7 +830,6 @@ dns_view_createresolver(dns_view_t *view,
 	event = &view->resevent;
 	dns_resolver_whenshutdown(view->resolver, view->task, &event);
 	view->attributes &= ~DNS_VIEWATTR_RESSHUTDOWN;
-	isc_refcount_increment(&view->weakrefs, NULL);
 
 	result = isc_mem_create(0, 0, &mctx);
 	if (result != ISC_R_SUCCESS) {
@@ -815,7 +847,6 @@ dns_view_createresolver(dns_view_t *view,
 	event = &view->adbevent;
 	dns_adb_whenshutdown(view->adb, view->task, &event);
 	view->attributes &= ~DNS_VIEWATTR_ADBSHUTDOWN;
-	isc_refcount_increment(&view->weakrefs, NULL);
 
 	result = dns_requestmgr_create(view->mctx, timermgr, socketmgr,
 				      dns_resolver_taskmgr(view->resolver),
@@ -830,7 +861,6 @@ dns_view_createresolver(dns_view_t *view,
 	event = &view->reqevent;
 	dns_requestmgr_whenshutdown(view->requestmgr, view->task, &event);
 	view->attributes &= ~DNS_VIEWATTR_REQSHUTDOWN;
-	isc_refcount_increment(&view->weakrefs, NULL);
 
 	return (ISC_R_SUCCESS);
 }
@@ -847,17 +877,12 @@ dns_view_setcache2(dns_view_t *view, dns_cache_t *cache, bool shared) {
 
 	view->cacheshared = shared;
 	if (view->cache != NULL) {
-		if (view->acache != NULL)
-			dns_acache_putdb(view->acache, view->cachedb);
 		dns_db_detach(&view->cachedb);
 		dns_cache_detach(&view->cache);
 	}
 	dns_cache_attach(cache, &view->cache);
 	dns_cache_attachdb(cache, &view->cachedb);
 	INSIST(DNS_DB_VALID(view->cachedb));
-
-	if (view->acache != NULL)
-		dns_acache_setdb(view->acache, view->cachedb);
 }
 
 bool
@@ -964,7 +989,9 @@ dns_view_addzone(dns_view_t *view, dns_zone_t *zone) {
 }
 
 isc_result_t
-dns_view_findzone(dns_view_t *view, dns_name_t *name, dns_zone_t **zonep) {
+dns_view_findzone(dns_view_t *view, const dns_name_t *name,
+		  dns_zone_t **zonep)
+{
 	isc_result_t result;
 
 	REQUIRE(DNS_VIEW_VALID(view));
@@ -984,7 +1011,7 @@ dns_view_findzone(dns_view_t *view, dns_name_t *name, dns_zone_t **zonep) {
 }
 
 isc_result_t
-dns_view_find(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
+dns_view_find(dns_view_t *view, const dns_name_t *name, dns_rdatatype_t type,
 	      isc_stdtime_t now, unsigned int options, bool use_hints,
 	      dns_db_t **dbp, dns_dbnode_t **nodep, dns_name_t *foundname,
 	      dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset) {
@@ -994,7 +1021,7 @@ dns_view_find(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
 }
 
 isc_result_t
-dns_view_find2(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
+dns_view_find2(dns_view_t *view, const dns_name_t *name, dns_rdatatype_t type,
 	       isc_stdtime_t now, unsigned int options,
 	       bool use_hints, bool use_static_stub,
 	       dns_db_t **dbp, dns_dbnode_t **nodep, dns_name_t *foundname,
@@ -1207,9 +1234,9 @@ dns_view_find2(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
 }
 
 isc_result_t
-dns_view_simplefind(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
-		    isc_stdtime_t now, unsigned int options,
-		    bool use_hints,
+dns_view_simplefind(dns_view_t *view, const dns_name_t *name,
+		    dns_rdatatype_t type, isc_stdtime_t now,
+		    unsigned int options, bool use_hints,
 		    dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset)
 {
 	isc_result_t result;
@@ -1251,8 +1278,8 @@ dns_view_simplefind(dns_view_t *view, dns_name_t *name, dns_rdatatype_t type,
 }
 
 isc_result_t
-dns_view_findzonecut(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
-		     isc_stdtime_t now, unsigned int options,
+dns_view_findzonecut(dns_view_t *view, const dns_name_t *name,
+		     dns_name_t *fname, isc_stdtime_t now, unsigned int options,
 		     bool use_hints,
 		     dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset)
 {
@@ -1262,10 +1289,11 @@ dns_view_findzonecut(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
 }
 
 isc_result_t
-dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
-		      isc_stdtime_t now, unsigned int options,
-		      bool use_hints,	bool use_cache,
-		      dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset)
+dns_view_findzonecut2(dns_view_t *view, const dns_name_t *name,
+		      dns_name_t *fname, isc_stdtime_t now,
+		      unsigned int options, bool use_hints,
+		      bool use_cache, dns_rdataset_t *rdataset,
+		      dns_rdataset_t *sigrdataset)
 {
 	isc_result_t result;
 	dns_db_t *db;
@@ -1301,9 +1329,8 @@ dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
 			ztoptions |= DNS_ZTFIND_NOEXACT;
 		result = dns_zt_find(view->zonetable, name, ztoptions,
 				     NULL, &zone);
-	} else {
+	} else
 		result = ISC_R_NOTFOUND;
-	}
 	UNLOCK(&view->lock);
 	if (result == ISC_R_SUCCESS || result == DNS_R_PARTIALMATCH)
 		result = dns_zone_getdb(zone, &db);
@@ -1318,15 +1345,12 @@ dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
 			 * We have a cache; try it.
 			 */
 			dns_db_attach(view->cachedb, &db);
-		} else if (use_hints && view->hints != NULL) {
+		} else {
 			/*
 			 * Maybe we have hints...
 			 */
 			try_hints = true;
 			goto finish;
-		} else {
-			result = DNS_R_NXDOMAIN;
-			goto cleanup;
 		}
 	} else if (result != ISC_R_SUCCESS) {
 		/*
@@ -1347,7 +1371,6 @@ dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
 			result = ISC_R_SUCCESS;
 		else if (result != ISC_R_SUCCESS)
 			goto cleanup;
-
 		if (use_cache && view->cachedb != NULL && db != view->hints) {
 			/*
 			 * We found an answer, but the cache may be better.
@@ -1389,15 +1412,11 @@ dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
 				 * have a zone delegation, so use it.
 				 */
 				use_zone = true;
-				result = ISC_R_SUCCESS;
-			} else if (use_hints && view->hints != NULL) {
+			} else {
 				/*
 				 * Maybe we have hints...
 				 */
 				try_hints = true;
-				result = ISC_R_SUCCESS;
-			} else {
-				result = DNS_R_NXDOMAIN;
 			}
 		} else {
 			/*
@@ -1422,7 +1441,7 @@ dns_view_findzonecut2(dns_view_t *view, dns_name_t *name, dns_name_t *fname,
 		if (sigrdataset != NULL &&
 		    dns_rdataset_isassociated(&zrdataset))
 			dns_rdataset_clone(&zsigrdataset, sigrdataset);
-	} else if (try_hints) {
+	} else if (try_hints && use_hints && view->hints != NULL) {
 		/*
 		 * We've found nothing so far, but we have hints.
 		 */
@@ -1477,7 +1496,7 @@ dns_viewlist_find(dns_viewlist_t *list, const char *name,
 }
 
 isc_result_t
-dns_viewlist_findzone(dns_viewlist_t *list, dns_name_t *name,
+dns_viewlist_findzone(dns_viewlist_t *list, const dns_name_t *name,
 		      bool allclasses, dns_rdataclass_t rdclass,
 		      dns_zone_t **zonep)
 {
@@ -1567,7 +1586,8 @@ dns_view_asyncload2(dns_view_t *view, dns_zt_allloaded_t callback, void *arg,
 }
 
 isc_result_t
-dns_view_gettsig(dns_view_t *view, dns_name_t *keyname, dns_tsigkey_t **keyp)
+dns_view_gettsig(dns_view_t *view, const dns_name_t *keyname,
+		 dns_tsigkey_t **keyp)
 {
 	isc_result_t result;
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -1581,7 +1601,7 @@ dns_view_gettsig(dns_view_t *view, dns_name_t *keyname, dns_tsigkey_t **keyp)
 }
 
 isc_result_t
-dns_view_getpeertsig(dns_view_t *view, isc_netaddr_t *peeraddr,
+dns_view_getpeertsig(dns_view_t *view, const isc_netaddr_t *peeraddr,
 		     dns_tsigkey_t **keyp)
 {
 	isc_result_t result;
@@ -1644,12 +1664,8 @@ dns_view_flushcache2(dns_view_t *view, bool fixuponly) {
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
-	if (view->acache != NULL)
-		dns_acache_putdb(view->acache, view->cachedb);
 	dns_db_detach(&view->cachedb);
 	dns_cache_attachdb(view->cache, &view->cachedb);
-	if (view->acache != NULL)
-		dns_acache_setdb(view->acache, view->cachedb);
 	if (view->resolver != NULL)
 		dns_resolver_flushbadcache(view->resolver, NULL);
 	if (view->failcache != NULL)
@@ -1660,12 +1676,14 @@ dns_view_flushcache2(dns_view_t *view, bool fixuponly) {
 }
 
 isc_result_t
-dns_view_flushname(dns_view_t *view, dns_name_t *name) {
+dns_view_flushname(dns_view_t *view, const dns_name_t *name) {
 	return (dns_view_flushnode(view, name, false));
 }
 
 isc_result_t
-dns_view_flushnode(dns_view_t *view, dns_name_t *name, bool tree) {
+dns_view_flushnode(dns_view_t *view, const dns_name_t *name,
+		   bool tree)
+{
 	isc_result_t result = ISC_R_SUCCESS;
 
 	REQUIRE(DNS_VIEW_VALID(view));
@@ -1693,7 +1711,7 @@ dns_view_flushnode(dns_view_t *view, dns_name_t *name, bool tree) {
 }
 
 isc_result_t
-dns_view_adddelegationonly(dns_view_t *view, dns_name_t *name) {
+dns_view_adddelegationonly(dns_view_t *view, const dns_name_t *name) {
 	isc_result_t result;
 	dns_name_t *item;
 	uint32_t hash;
@@ -1728,7 +1746,7 @@ dns_view_adddelegationonly(dns_view_t *view, dns_name_t *name) {
 }
 
 isc_result_t
-dns_view_excludedelegationonly(dns_view_t *view, dns_name_t *name) {
+dns_view_excludedelegationonly(dns_view_t *view, const dns_name_t *name) {
 	isc_result_t result;
 	dns_name_t *item;
 	uint32_t hash;
@@ -1763,7 +1781,7 @@ dns_view_excludedelegationonly(dns_view_t *view, dns_name_t *name) {
 }
 
 bool
-dns_view_isdelegationonly(dns_view_t *view, dns_name_t *name) {
+dns_view_isdelegationonly(dns_view_t *view, const dns_name_t *name) {
 	dns_name_t *item;
 	uint32_t hash;
 
@@ -1911,7 +1929,7 @@ dns_view_getsecroots(dns_view_t *view, dns_keytable_t **ktp) {
 
 bool
 dns_view_ntacovers(dns_view_t *view, isc_stdtime_t now,
-		   dns_name_t *name, dns_name_t *anchor)
+		   const dns_name_t *name, const dns_name_t *anchor)
 {
 	REQUIRE(DNS_VIEW_VALID(view));
 
@@ -1922,8 +1940,8 @@ dns_view_ntacovers(dns_view_t *view, isc_stdtime_t now,
 }
 
 isc_result_t
-dns_view_issecuredomain(dns_view_t *view, dns_name_t *name,
-			isc_stdtime_t now, bool checknta, bool *ntap,
+dns_view_issecuredomain(dns_view_t *view, const dns_name_t *name,
+			isc_stdtime_t now, bool checknta,
 			bool *secure_domain)
 {
 	isc_result_t result;
@@ -1933,36 +1951,26 @@ dns_view_issecuredomain(dns_view_t *view, dns_name_t *name,
 
 	REQUIRE(DNS_VIEW_VALID(view));
 
-	if (view->secroots_priv == NULL) {
+	if (view->secroots_priv == NULL)
 		return (ISC_R_NOTFOUND);
-	}
 
 	anchor = dns_fixedname_initname(&fn);
 
 	result = dns_keytable_issecuredomain(view->secroots_priv, name,
 					     anchor, &secure);
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		return (result);
-	}
 
-	if (ntap != NULL) {
-		*ntap = false;
-	}
 	if (checknta && secure && view->ntatable_priv != NULL &&
 	    dns_ntatable_covered(view->ntatable_priv, now, name, anchor))
-	{
-		if (ntap != NULL) {
-			*ntap = true;
-		}
 		secure = false;
-	}
 
 	*secure_domain = secure;
 	return (ISC_R_SUCCESS);
 }
 
 void
-dns_view_untrust(dns_view_t *view, dns_name_t *keyname,
+dns_view_untrust(dns_view_t *view, const dns_name_t *keyname,
 		 dns_rdata_dnskey_t *dnskey, isc_mem_t *mctx)
 {
 	isc_result_t result;
@@ -2008,6 +2016,61 @@ dns_view_untrust(dns_view_t *view, dns_name_t *keyname,
 	dst_key_free(&key);
 }
 
+/*
+ * Create path to a directory and a filename contructed from viewname.
+ * This is a front-end to isc_file_sanitize(), allowing backward
+ * compatibility to older versions when a file couldn't be expected
+ * to be in the specified directory but might be in the current working
+ * directory instead.
+ *
+ * It first tests for the existence of a file <viewname>.<suffix> in
+ * 'directory'. If the file does not exist, it checks again in the
+ * current working directory. If it does not exist there either,
+ * return the path inside the directory.
+ *
+ * Returns ISC_R_SUCCESS if a path to an existing file is found or
+ * a new path is created; returns ISC_R_NOSPACE if the path won't
+ * fit in 'buflen'.
+ */
+
+#ifndef PATH_MAX
+#define PATH_MAX 1024
+#endif
+
+static isc_result_t
+nz_legacy(const char *directory, const char *viewname,
+	  const char *suffix, char *buffer, size_t buflen)
+{
+	isc_result_t result;
+	char newbuf[PATH_MAX];
+
+	result = isc_file_sanitize(directory, viewname, suffix,
+				   buffer, buflen);
+	if (result != ISC_R_SUCCESS) {
+		return (result);
+	} else if (directory == NULL || isc_file_exists(buffer)) {
+		return (ISC_R_SUCCESS);
+	} else {
+		/* Save buffer */
+		strlcpy(newbuf, buffer, sizeof(newbuf));
+	}
+
+	/*
+	 * It isn't in the specified directory; check CWD.
+	 */
+	result = isc_file_sanitize(NULL, viewname, suffix, buffer, buflen);
+	if (result != ISC_R_SUCCESS || isc_file_exists(buffer)) {
+		return (result);
+	}
+
+	/*
+	 * File does not exist in either 'directory' or CWD,
+	 * so use the path in 'directory'.
+	 */
+	strlcpy(buffer, newbuf, buflen);
+	return (ISC_R_SUCCESS);
+}
+
 isc_result_t
 dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
 		     void (*cfg_destroy)(void **), uint64_t mapsize)
@@ -2048,11 +2111,12 @@ dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
 		view->cfg_destroy = NULL;
 	}
 
-	if (!allow)
+	if (!allow) {
 		return (ISC_R_SUCCESS);
+	}
 
-	CHECK(isc_file_sanitize(NULL, view->name, "nzf",
-				buffer, sizeof(buffer)));
+	CHECK(nz_legacy(view->new_zone_dir, view->name, "nzf",
+			buffer, sizeof(buffer)));
 
 	view->new_zone_file = isc_mem_strdup(view->mctx, buffer);
 	if (view->new_zone_file == NULL) {
@@ -2060,8 +2124,8 @@ dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
 	}
 
 #ifdef HAVE_LMDB
-	CHECK(isc_file_sanitize(NULL, view->name, "nzd",
-				buffer, sizeof(buffer)));
+	CHECK(nz_legacy(view->new_zone_dir, view->name, "nzd",
+			buffer, sizeof(buffer)));
 
 	view->new_zone_db = isc_mem_strdup(view->mctx, buffer);
 	if (view->new_zone_db == NULL) {
@@ -2128,11 +2192,33 @@ dns_view_setnewzones(dns_view_t *view, bool allow, void *cfgctx,
 	return (result);
 }
 
+void
+dns_view_setnewzonedir(dns_view_t *view, const char *dir) {
+	REQUIRE(DNS_VIEW_VALID(view));
+
+	if (view->new_zone_dir != NULL) {
+		isc_mem_free(view->mctx, view->new_zone_dir);
+		view->new_zone_dir = NULL;
+	}
+
+	if (dir == NULL) {
+		return;
+	}
+
+	view->new_zone_dir = isc_mem_strdup(view->mctx, dir);
+}
+
+const char *
+dns_view_getnewzonedir(dns_view_t *view) {
+	REQUIRE(DNS_VIEW_VALID(view));
+
+	return (view->new_zone_dir);
+}
+
 isc_result_t
-dns_view_searchdlz(dns_view_t *view, dns_name_t *name, unsigned int minlabels,
-		   dns_clientinfomethods_t *methods,
-		   dns_clientinfo_t *clientinfo,
-		   dns_db_t **dbp)
+dns_view_searchdlz(dns_view_t *view, const dns_name_t *name,
+		   unsigned int minlabels, dns_clientinfomethods_t *methods,
+		   dns_clientinfo_t *clientinfo, dns_db_t **dbp)
 {
 	dns_fixedname_t fname;
 	dns_name_t *zonename;
@@ -2299,7 +2385,7 @@ dns_view_loadnta(dns_view_t *view) {
 		char *name, *type, *timestamp;
 		size_t len;
 		dns_fixedname_t fn;
-		dns_name_t *ntaname;
+		const dns_name_t *ntaname;
 		isc_buffer_t b;
 		isc_stdtime_t t;
 		bool forced;
@@ -2315,12 +2401,14 @@ dns_view_loadnta(dns_view_t *view) {
 		if (strcmp(name, ".") == 0)
 			ntaname = dns_rootname;
 		else {
-			ntaname = dns_fixedname_initname(&fn);
+			dns_name_t *fname;
+			fname = dns_fixedname_initname(&fn);
 
 			isc_buffer_init(&b, name, (unsigned int)len);
 			isc_buffer_add(&b, (unsigned int)len);
-			CHECK(dns_name_fromtext(ntaname, &b, dns_rootname,
+			CHECK(dns_name_fromtext(fname, &b, dns_rootname,
 						0, NULL));
+			ntaname = fname;
 		}
 
 		CHECK(isc_lex_gettoken(lex, options, &token));
