@@ -43,6 +43,7 @@
 
 #include <ctype.h>
 #include <errno.h>
+#include <inttypes.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -97,7 +98,7 @@ struct irs_resconf {
 
 	char	       		*domainname;
 	char 	       		*search[RESCONFMAXSEARCH];
-	isc_uint8_t		searchnxt; /*%< index for next free slot */
+	uint8_t		searchnxt; /*%< index for next free slot */
 
 	irs_resconf_searchlist_t searchlist;
 
@@ -106,12 +107,12 @@ struct irs_resconf {
 		/*% mask has a non-zero 'family' if set */
 		isc_netaddr_t	mask;
 	} sortlist[RESCONFMAXSORTLIST];
-	isc_uint8_t		sortlistnxt;
+	uint8_t		sortlistnxt;
 
 	/*%< non-zero if 'options debug' set */
-	isc_uint8_t		resdebug;
+	uint8_t		resdebug;
 	/*%< set to n in 'options ndots:n' */
-	isc_uint8_t		ndots;
+	uint8_t		ndots;
 };
 
 static isc_result_t
@@ -125,6 +126,10 @@ resconf_parsesortlist(irs_resconf_t *conf,  FILE *fp);
 static isc_result_t
 resconf_parseoption(irs_resconf_t *ctx,  FILE *fp);
 
+#if HAVE_GET_WIN32_NAMESERVERS
+static isc_result_t get_win32_nameservers(irs_resconf_t *conf);
+#endif
+
 /*!
  * Eat characters from FP until EOL or EOF. Returns EOF or '\n'
  */
@@ -453,7 +458,7 @@ resconf_parseoption(irs_resconf_t *conf,  FILE *fp) {
 				return (ISC_R_UNEXPECTEDTOKEN);
 			if (ndots < 0 || ndots > 0xff) /* Out of range. */
 				return (ISC_R_RANGE);
-			conf->ndots = (isc_uint8_t)ndots;
+			conf->ndots = (uint8_t)ndots;
 		}
 
 		if (delim == EOF || delim == '\n')
@@ -561,15 +566,6 @@ irs_resconf_load(isc_mem_t *mctx, const char *filename, irs_resconf_t **confp)
 		goto error;
 	}
 
-	/* If we don't find a nameserver fall back to localhost */
-	if (conf->numns == 0U) {
-		INSIST(ISC_LIST_EMPTY(conf->nameservers));
-
-		/* XXX: should we catch errors? */
-		(void)add_server(conf->mctx, "::1", &conf->nameservers);
-		(void)add_server(conf->mctx, "127.0.0.1", &conf->nameservers);
-	}
-
 	/*
 	 * Construct unified search list from domain or configured
 	 * search list
@@ -584,6 +580,22 @@ irs_resconf_load(isc_mem_t *mctx, const char *filename, irs_resconf_t **confp)
 		}
 	}
 
+#if HAVE_GET_WIN32_NAMESERVERS
+	ret = get_win32_nameservers(conf);
+	if (ret != ISC_R_SUCCESS) {
+		goto error;
+	}
+#endif
+
+	/* If we don't find a nameserver fall back to localhost */
+	if (conf->numns == 0U) {
+		INSIST(ISC_LIST_EMPTY(conf->nameservers));
+
+		/* XXX: should we catch errors? */
+		(void)add_server(conf->mctx, "::1", &conf->nameservers);
+		(void)add_server(conf->mctx, "127.0.0.1", &conf->nameservers);
+	}
+
  error:
 	conf->magic = IRS_RESCONF_MAGIC;
 
