@@ -17,7 +17,6 @@
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -71,6 +70,9 @@ irs_resconf_load_test(void **state) {
 		}, {
 			"testdata/nameserver-v6.conf", ISC_R_SUCCESS,
 			NULL, ISC_R_SUCCESS
+		}, {
+			"testdata/nameserver-v6-scoped.conf", ISC_R_SUCCESS,
+			NULL, ISC_R_SUCCESS
 		}, {
 			"testdata/options-debug.conf", ISC_R_SUCCESS,
 			NULL, ISC_R_SUCCESS
