@@ -34,6 +34,7 @@
 
 #include <config.h>
 
+#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>		/* Required for time(). */
 #ifdef HAVE_SYS_TYPES_H
@@ -76,7 +77,7 @@ struct isc_rng {
 	unsigned int	magic;
 	isc_mem_t	*mctx;
 	chacha_ctx	cpctx;
-	isc_uint8_t	buffer[CHACHA_BUFFERSIZE];
+	uint8_t	buffer[CHACHA_BUFFERSIZE];
 	size_t		have;
 	unsigned int	references;
 	int		count;
@@ -107,7 +108,7 @@ initialize(void) {
 }
 
 void
-isc_random_seed(isc_uint32_t seed) {
+isc_random_seed(uint32_t seed) {
 	initialize();
 
 #ifndef HAVE_ARC4RANDOM
@@ -117,7 +118,7 @@ isc_random_seed(isc_uint32_t seed) {
 	UNUSED(seed);
 	arc4random_stir();
 #elif defined(HAVE_ARC4RANDOM_ADDRANDOM)
-	arc4random_addrandom((u_char *) &seed, sizeof(isc_uint32_t));
+	arc4random_addrandom((u_char *) &seed, sizeof(uint32_t));
 #else
        /*
 	* If arc4random() is available and no corresponding seeding
@@ -131,7 +132,7 @@ isc_random_seed(isc_uint32_t seed) {
 }
 
 void
-isc_random_get(isc_uint32_t *val) {
+isc_random_get(uint32_t *val) {
 	REQUIRE(val != NULL);
 
 	initialize();
@@ -157,9 +158,9 @@ isc_random_get(isc_uint32_t *val) {
 #endif
 }
 
-isc_uint32_t
-isc_random_jitter(isc_uint32_t max, isc_uint32_t jitter) {
-	isc_uint32_t rnd;
+uint32_t
+isc_random_jitter(uint32_t max, uint32_t jitter) {
+	uint32_t rnd;
 
 	REQUIRE(jitter < max || (jitter == 0 && max == 0));
 
@@ -171,7 +172,7 @@ isc_random_jitter(isc_uint32_t max, isc_uint32_t jitter) {
 }
 
 static void
-chacha_reinit(isc_rng_t *rng, isc_uint8_t *buffer, size_t n) {
+chacha_reinit(isc_rng_t *rng, uint8_t *buffer, size_t n) {
 	REQUIRE(rng != NULL);
 
 	if (n < CHACHA_KEYSIZE + CHACHA_IVSIZE)
@@ -185,7 +186,7 @@ isc_result_t
 isc_rng_create(isc_mem_t *mctx, isc_entropy_t *entropy, isc_rng_t **rngp) {
 	union {
 		unsigned char rnd[128];
-		isc_uint32_t rnd32[32];
+		uint32_t rnd32[32];
 	} rnd;
 	isc_result_t result;
 	isc_rng_t *rng;
@@ -263,7 +264,7 @@ destroy(isc_rng_t *rng) {
 void
 isc_rng_detach(isc_rng_t **rngp) {
 	isc_rng_t *rng;
-	isc_boolean_t dest = ISC_FALSE;
+	bool dest = false;
 
 	REQUIRE(rngp != NULL && VALID_RNG(*rngp));
 
@@ -275,7 +276,7 @@ isc_rng_detach(isc_rng_t **rngp) {
 	INSIST(rng->references > 0);
 	rng->references--;
 	if (rng->references == 0)
-		dest = ISC_TRUE;
+		dest = true;
 	UNLOCK(&rng->lock);
 
 	if (dest)
@@ -311,7 +312,7 @@ chacha_rekey(isc_rng_t *rng, u_char *dat, size_t datlen) {
 }
 
 static void
-chacha_getbytes(isc_rng_t *rng, isc_uint8_t *output, size_t length) {
+chacha_getbytes(isc_rng_t *rng, uint8_t *output, size_t length) {
 	REQUIRE(VALID_RNG(rng));
 
 	while (ISC_UNLIKELY(length > CHACHA_MAXHAVE)) {
@@ -336,7 +337,7 @@ static void
 chacha_stir(isc_rng_t *rng) {
 	union {
 		unsigned char rnd[128];
-		isc_uint32_t rnd32[32];
+		uint32_t rnd32[32];
 	} rnd;
 	isc_result_t result;
 
@@ -373,7 +374,7 @@ chacha_stir(isc_rng_t *rng) {
 
 void
 isc_rng_randombytes(isc_rng_t *rng, void *output, size_t length) {
-	isc_uint8_t *ptr = output;
+	uint8_t *ptr = output;
 
 	REQUIRE(VALID_RNG(rng));
 	REQUIRE(output != NULL && length > 0);
@@ -397,18 +398,18 @@ isc_rng_randombytes(isc_rng_t *rng, void *output, size_t length) {
 	UNLOCK(&rng->lock);
 }
 
-isc_uint16_t
+uint16_t
 isc_rng_random(isc_rng_t *rng) {
-	isc_uint16_t result;
+	uint16_t result;
 
 	isc_rng_randombytes(rng, &result, sizeof(result));
 
 	return (result);
 }
 
-isc_uint16_t
-isc_rng_uniformrandom(isc_rng_t *rng, isc_uint16_t upper_bound) {
-	isc_uint16_t min, r;
+uint16_t
+isc_rng_uniformrandom(isc_rng_t *rng, uint16_t upper_bound) {
+	uint16_t min, r;
 
 	REQUIRE(VALID_RNG(rng));
 
@@ -423,7 +424,7 @@ isc_rng_uniformrandom(isc_rng_t *rng, isc_uint16_t upper_bound) {
 	if (upper_bound > 0x8000)
 		min = 1 + ~upper_bound; /* 0x8000 - upper_bound */
 	else
-		min = (isc_uint16_t)(0x10000 % (isc_uint32_t)upper_bound);
+		min = (uint16_t)(0x10000 % (uint32_t)upper_bound);
 
 	/*
 	 * This could theoretically loop forever but each retry has
