@@ -368,7 +368,7 @@ cfg_tuple_get(const cfg_obj_t *tupleobj, const char* name) {
 			return (tupleobj->value.tuple[i]);
 	}
 	INSIST(0);
-	return (NULL);
+	ISC_UNREACHABLE();
 }
 
 isc_result_t
@@ -1803,7 +1803,8 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 			/* Single-valued clause */
 			if (result == ISC_R_NOTFOUND) {
 				bool callback =
-					(clause->flags & CFG_CLAUSEFLAG_CALLBACK);
+					((clause->flags &
+					  CFG_CLAUSEFLAG_CALLBACK) != 0);
 				CHECK(parse_symtab_elt(pctx, clause->name,
 						       clause->type,
 						       obj->value.map.symtab,
@@ -1988,6 +1989,7 @@ cfg_print_mapbody(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 				; /* do nothing */
 			} else {
 				INSIST(0);
+				ISC_UNREACHABLE();
 			}
 		}
 	}
@@ -2303,6 +2305,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 			return (ISC_R_SUCCESS);
 		} else {
 			INSIST(0);
+			ISC_UNREACHABLE();
 		}
 	} else {
 		if ((flags & (CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK)) != 0) {
@@ -2504,27 +2507,29 @@ static void
 cfg_doc_netaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	const unsigned int *flagp = type->of;
 	int n = 0;
-	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK)
+	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK) {
 		cfg_print_cstr(pctx, "( ");
-	if (*flagp & CFG_ADDR_V4OK) {
+	}
+	if ((*flagp & CFG_ADDR_V4OK) != 0) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
 		n++;
 	}
-	if (*flagp & CFG_ADDR_V6OK) {
+	if ((*flagp & CFG_ADDR_V6OK) != 0) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "<ipv6_address>");
 		n++;
 	}
-	if (*flagp & CFG_ADDR_WILDOK) {
+	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "*");
 		n++;
 		POST(n);
 	}
-	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK)
+	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK) {
 		cfg_print_cstr(pctx, " )");
+	}
 }
 
 LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_netaddr = {
@@ -2579,7 +2584,7 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		break;
 	default:
 		INSIST(0);
-		break;
+		ISC_UNREACHABLE();
 	}
 	CHECK(cfg_peektoken(pctx, 0));
 	if (pctx->token.type == isc_tokentype_special &&
@@ -2752,17 +2757,17 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	REQUIRE(type != NULL);
 
 	cfg_print_cstr(pctx, "( ");
-	if (*flagp & CFG_ADDR_V4OK) {
+	if ((*flagp & CFG_ADDR_V4OK) != 0) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
 		n++;
 	}
-	if (*flagp & CFG_ADDR_V6OK) {
+	if ((*flagp & CFG_ADDR_V6OK) != 0) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "<ipv6_address>");
 		n++;
 	}
-	if (*flagp & CFG_ADDR_WILDOK) {
+	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "*");
@@ -2770,7 +2775,7 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 		POST(n);
 	}
 	cfg_print_cstr(pctx, " ) ");
-	if (*flagp & CFG_ADDR_WILDOK) {
+	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
 		cfg_print_cstr(pctx, "[ port ( <integer> | * ) ]");
 	} else {
 		cfg_print_cstr(pctx, "[ port <integer> ]");
@@ -3011,12 +3016,13 @@ parser_complain(cfg_parser_t *pctx, bool is_warning,
 		}
 
 		/* Choose a preposition. */
-		if (flags & CFG_LOG_NEAR)
+		if ((flags & CFG_LOG_NEAR) != 0) {
 			prep = " near ";
-		else if (flags & CFG_LOG_BEFORE)
+		} else if ((flags & CFG_LOG_BEFORE) != 0) {
 			prep = " before ";
-		else
+		} else {
 			prep = " ";
+		}
 	} else {
 		tokenbuf[0] = '\0';
 	}
